/* original parser id follows */
/* yysccsid[] = "@(#)yaccpar	1.9 (Berkeley) 02/21/93" */
/* (use YYMAJOR/YYMINOR for ifdefs dependent on parser version) */

#define YYBYACC 1
#define YYMAJOR 1
#define YYMINOR 9
#define YYPATCH 20170709

#define YYEMPTY        (-1)
#define yyclearin      (yychar = YYEMPTY)
#define yyerrok        (yyerrflag = 0)
#define YYRECOVERING() (yyerrflag != 0)
#define YYENOMEM       (-2)
#define YYEOF          0
#define YYPREFIX "yy"

#define YYPURE 0

#line 2 "src/asm/asmy.y"
#include <ctype.h>
#include <errno.h>
#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <strings.h>

#include "asm/symbol.h"
#include "asm/asm.h"
#include "asm/charmap.h"
#include "asm/output.h"
#include "asm/mylink.h"
#include "asm/fstack.h"
#include "asm/mymath.h"
#include "asm/rpn.h"
#include "asm/main.h"
#include "asm/lexer.h"

char	*tzNewMacro;
ULONG	ulNewMacroSize;

void
bankrangecheck(char *name, ULONG secttype, SLONG org, SLONG bank)
{
	SLONG minbank, maxbank;
	char *stype = NULL;
	switch (secttype) {
	case SECT_ROMX:
		stype = "ROMX";
		minbank = 1;
		maxbank = 0x1ff;
		break;
	case SECT_SRAM:
		stype = "SRAM";
		minbank = 0;
		maxbank = 0x1ff;
		break;
	case SECT_WRAMX:
		stype = "WRAMX";
		minbank = 1;
		maxbank = 7;
		break;
	case SECT_VRAM:
		stype = "VRAM";
		minbank = 0;
		maxbank = 1;
		break;
	default:
		yyerror("BANK only allowed for "
		    "ROMX, WRAMX, SRAM, or VRAM sections");
	}

	if (stype && (bank < minbank || bank > maxbank)) {
		yyerror("%s bank value $%x out of range ($%x to $%x)",
		    stype, bank, minbank, maxbank);
	}

	if (secttype == SECT_WRAMX) {
		bank -= minbank;
	}

	out_NewAbsSection(name, secttype, org, bank);
}

size_t symvaluetostring(char *dest, size_t maxLength, char *sym)
{
	size_t length;

	if (sym_isString(sym)) {
		char *src = sym_GetStringValue(sym);
		size_t i;

		for (i = 0; src[i] != 0; i++) {
			if (i >= maxLength) {
				fatalerror("Symbol value too long to fit buffer");
			}
			dest[i] = src[i];
		}

		length = i;
	} else {
		ULONG value = sym_GetConstantValue(sym);
		int fullLength = snprintf(dest, maxLength + 1, "$%lX", value);

		if (fullLength < 0) {
			fatalerror("snprintf encoding error");
		} else {
			length = (size_t)fullLength;

			if (length > maxLength) {
				fatalerror("Symbol value too long to fit buffer");
			}
		}
	}

	return length;
}

ULONG	str2int( char *s )
{
	ULONG r=0;
	while( *s )
	{
		r<<=8;
		r|=(UBYTE)(*s++);
	}
	return( r );
}

ULONG	str2int2( char *s, int length )
{
	int i;
	ULONG r=0;
	i = (length - 4 < 0 ? 0 : length - 4);
	while(i < length)
	{
		r<<=8;
		r|=(UBYTE)(s[i]);
		i++;
	}
	return( r );
}

ULONG	isWhiteSpace( char s )
{
	return( s==' ' || s=='\t' || s=='\0' || s=='\n' );
}

ULONG	isRept( char *s )
{
	return( (strncasecmp(s,"REPT",4)==0) && isWhiteSpace(*(s-1)) && isWhiteSpace(s[4]) );
}

ULONG	isEndr( char *s )
{
	return( (strncasecmp(s,"Endr",4)==0) && isWhiteSpace(*(s-1)) && isWhiteSpace(s[4]) );
}

void	copyrept( void )
{
	SLONG	level=1, len, instring=0;
	char	*src=pCurrentBuffer->pBuffer;
	char	*bufferEnd = pCurrentBuffer->pBufferStart + pCurrentBuffer->nBufferSize;

	while( src < bufferEnd && level )
	{
		if( instring==0 )
		{
			if( isRept(src) )
			{
				level+=1;
				src+=4;
			}
			else if( isEndr(src) )
			{
				level-=1;
				src+=4;
			}
			else
			{
				if( *src=='\"' )
					instring=1;
				src+=1;
			}
		}
		else
		{
			if( *src=='\\' )
			{
				src+=2;
			}
			else if( *src=='\"' )
			{
				src+=1;
				instring=0;
			}
			else
			{
				src+=1;
			}
		}
	}

	if (level != 0) {
		fatalerror("Unterminated REPT block");
	}

	len=src-pCurrentBuffer->pBuffer-4;

	src=pCurrentBuffer->pBuffer;
	ulNewMacroSize=len;

	if ((tzNewMacro = malloc(ulNewMacroSize + 1)) != NULL) {
		ULONG i;

		tzNewMacro[ulNewMacroSize]=0;
		for( i=0; i<ulNewMacroSize; i+=1 )
		{
			if( (tzNewMacro[i]=src[i])=='\n' )
				nLineNo+=1;
		}
	} else
		fatalerror( "No mem for REPT block" );

	yyskipbytes( ulNewMacroSize+4 );

}

ULONG	isMacro( char *s )
{
	return( (strncasecmp(s,"MACRO",4)==0) && isWhiteSpace(*(s-1)) && isWhiteSpace(s[5]) );
}

ULONG	isEndm( char *s )
{
	return( (strncasecmp(s,"Endm",4)==0) && isWhiteSpace(*(s-1)) && isWhiteSpace(s[4]) );
}

void	copymacro( void )
{
	SLONG	level=1, len, instring=0;
	char	*src=pCurrentBuffer->pBuffer;
	char	*bufferEnd = pCurrentBuffer->pBufferStart + pCurrentBuffer->nBufferSize;

	while( src < bufferEnd && level )
	{
		if( instring==0 )
		{
			if( isMacro(src) )
			{
				level+=1;
				src+=4;
			}
			else if( isEndm(src) )
			{
				level-=1;
				src+=4;
			}
			else
			{
				if( *src=='\"' )
					instring=1;
				src+=1;
			}
		}
		else
		{
			if( *src=='\\' )
			{
				src+=2;
			}
			else if( *src=='\"' )
			{
				src+=1;
				instring=0;
			}
			else
			{
				src+=1;
			}
		}
	}

	if (level != 0) {
		fatalerror("Unterminated MACRO definition");
	}

	len=src-pCurrentBuffer->pBuffer-4;

	src=pCurrentBuffer->pBuffer;
	ulNewMacroSize=len;

	if( (tzNewMacro=(char *)malloc(ulNewMacroSize+2))!=NULL )
	{
		ULONG i;

		tzNewMacro[ulNewMacroSize]='\n';
		tzNewMacro[ulNewMacroSize+1]=0;
		for( i=0; i<ulNewMacroSize; i+=1 )
		{
			if( (tzNewMacro[i]=src[i])=='\n' )
				nLineNo+=1;
		}
	}
	else
		fatalerror( "No mem for MACRO definition" );

	yyskipbytes( ulNewMacroSize+4 );
}

ULONG	isIf( char *s )
{
	return( (strncasecmp(s,"If",2)==0) && isWhiteSpace(*(s-1)) && isWhiteSpace(s[2]) );
}

ULONG	isElse( char *s )
{
	return( (strncasecmp(s,"Else",4)==0) && isWhiteSpace(*(s-1)) && isWhiteSpace(s[4]) );
}

ULONG	isEndc( char *s )
{
	return( (strncasecmp(s,"Endc",4)==0) && isWhiteSpace(*(s-1)) && isWhiteSpace(s[4]) );
}

void	if_skip_to_else( void )
{
	SLONG	level=1, len, instring=0;
	char	*src=pCurrentBuffer->pBuffer;

	while( *src && level )
	{
		if( *src=='\n' )
			nLineNo+=1;

		if( instring==0 )
		{
			if( isIf(src) )
			{
				level+=1;
				src+=2;
			}
			else if( level==1 && isElse(src) )
			{
				level-=1;
				src+=4;
			}
			else if( isEndc(src) )
			{
				level-=1;
				if( level!=0 )
					src+=4;
			}
			else
			{
				if( *src=='\"' )
					instring=1;
				src+=1;
			}
		}
		else
		{
			if( *src=='\\' )
			{
				src+=2;
			}
			else if( *src=='\"' )
			{
				src+=1;
				instring=0;
			}
			else
			{
				src+=1;
			}
		}
	}

	if (level != 0) {
		fatalerror("Unterminated IF construct");
	}

	len=src-pCurrentBuffer->pBuffer;

	yyskipbytes( len );
	yyunput( '\n' );
	nLineNo-=1;
}

void	if_skip_to_endc( void )
{
	SLONG	level=1, len, instring=0;
	char	*src=pCurrentBuffer->pBuffer;

	while( *src && level )
	{
		if( *src=='\n' )
			nLineNo+=1;

		if( instring==0 )
		{
			if( isIf(src) )
			{
				level+=1;
				src+=2;
			}
			else if( isEndc(src) )
			{
				level-=1;
				if( level!=0 )
					src+=4;
			}
			else
			{
				if( *src=='\"' )
					instring=1;
				src+=1;
			}
		}
		else
		{
			if( *src=='\\' )
			{
				src+=2;
			}
			else if( *src=='\"' )
			{
				src+=1;
				instring=0;
			}
			else
			{
				src+=1;
			}
		}
	}

	if (level != 0) {
		fatalerror("Unterminated IF construct");
	}

	len=src-pCurrentBuffer->pBuffer;

	yyskipbytes( len );
	yyunput( '\n' );
	nLineNo-=1;
}

#ifdef YYSTYPE
#undef  YYSTYPE_IS_DECLARED
#define YYSTYPE_IS_DECLARED 1
#endif
#ifndef YYSTYPE_IS_DECLARED
#define YYSTYPE_IS_DECLARED 1
#line 432 "src/asm/asmy.y"
typedef union
{
    char tzSym[MAXSYMLEN + 1];
    char tzString[MAXSTRLEN + 1];
    struct Expression sVal;
    SLONG nConstValue;
} YYSTYPE;
#endif /* !YYSTYPE_IS_DECLARED */
#line 465 "src/asm/asmy.c"

/* compatibility with bison */
#ifdef YYPARSE_PARAM
/* compatibility with FreeBSD */
# ifdef YYPARSE_PARAM_TYPE
#  define YYPARSE_DECL() yyparse(YYPARSE_PARAM_TYPE YYPARSE_PARAM)
# else
#  define YYPARSE_DECL() yyparse(void *YYPARSE_PARAM)
# endif
#else
# define YYPARSE_DECL() yyparse(void)
#endif

/* Parameters sent to lex. */
#ifdef YYLEX_PARAM
# define YYLEX_DECL() yylex(void *YYLEX_PARAM)
# define YYLEX yylex(YYLEX_PARAM)
#else
# define YYLEX_DECL() yylex(void)
# define YYLEX yylex()
#endif

/* Parameters sent to yyerror. */
#ifndef YYERROR_DECL
#define YYERROR_DECL() yyerror(const char *s)
#endif
#ifndef YYERROR_CALL
#define YYERROR_CALL(msg) yyerror(msg)
#endif

extern int YYPARSE_DECL();

#define T_NUMBER 257
#define T_STRING 258
#define T_OP_LOGICNOT 259
#define T_OP_LOGICOR 260
#define T_OP_LOGICAND 261
#define T_OP_LOGICEQU 262
#define T_OP_LOGICGT 263
#define T_OP_LOGICLT 264
#define T_OP_LOGICGE 265
#define T_OP_LOGICLE 266
#define T_OP_LOGICNE 267
#define T_OP_ADD 268
#define T_OP_SUB 269
#define T_OP_OR 270
#define T_OP_XOR 271
#define T_OP_AND 272
#define T_OP_SHL 273
#define T_OP_SHR 274
#define T_OP_MUL 275
#define T_OP_DIV 276
#define T_OP_MOD 277
#define T_OP_NOT 278
#define T_OP_DEF 279
#define T_OP_BANK 280
#define T_OP_ALIGN 281
#define T_OP_SIN 282
#define T_OP_COS 283
#define T_OP_TAN 284
#define T_OP_ASIN 285
#define T_OP_ACOS 286
#define T_OP_ATAN 287
#define T_OP_ATAN2 288
#define T_OP_FDIV 289
#define T_OP_FMUL 290
#define T_OP_ROUND 291
#define T_OP_CEIL 292
#define T_OP_FLOOR 293
#define T_OP_HIGH 294
#define T_OP_LOW 295
#define T_OP_STRCMP 296
#define T_OP_STRIN 297
#define T_OP_STRSUB 298
#define T_OP_STRLEN 299
#define T_OP_STRCAT 300
#define T_OP_STRUPR 301
#define T_OP_STRLWR 302
#define NEG 303
#define T_LABEL 304
#define T_ID 305
#define T_POP_EQU 306
#define T_POP_SET 307
#define T_POP_EQUS 308
#define T_POP_INCLUDE 309
#define T_POP_PRINTF 310
#define T_POP_PRINTT 311
#define T_POP_PRINTV 312
#define T_POP_IF 313
#define T_POP_ELSE 314
#define T_POP_ENDC 315
#define T_POP_IMPORT 316
#define T_POP_EXPORT 317
#define T_POP_GLOBAL 318
#define T_POP_DB 319
#define T_POP_DS 320
#define T_POP_DW 321
#define T_POP_DL 322
#define T_POP_SECTION 323
#define T_POP_RB 324
#define T_POP_RW 325
#define T_POP_RL 326
#define T_POP_MACRO 327
#define T_POP_ENDM 328
#define T_POP_RSRESET 329
#define T_POP_RSSET 330
#define T_POP_INCBIN 331
#define T_POP_REPT 332
#define T_POP_CHARMAP 333
#define T_POP_SHIFT 334
#define T_POP_ENDR 335
#define T_POP_FAIL 336
#define T_POP_WARN 337
#define T_POP_PURGE 338
#define T_POP_POPS 339
#define T_POP_PUSHS 340
#define T_POP_POPO 341
#define T_POP_PUSHO 342
#define T_POP_OPT 343
#define T_SECT_WRAM0 344
#define T_SECT_VRAM 345
#define T_SECT_ROMX 346
#define T_SECT_ROM0 347
#define T_SECT_HRAM 348
#define T_SECT_WRAMX 349
#define T_SECT_SRAM 350
#define T_SECT_OAM 351
#define T_SECT_HOME 352
#define T_SECT_DATA 353
#define T_SECT_CODE 354
#define T_SECT_BSS 355
#define T_Z80_ADC 356
#define T_Z80_ADD 357
#define T_Z80_AND 358
#define T_Z80_BIT 359
#define T_Z80_CALL 360
#define T_Z80_CCF 361
#define T_Z80_CP 362
#define T_Z80_CPL 363
#define T_Z80_DAA 364
#define T_Z80_DEC 365
#define T_Z80_DI 366
#define T_Z80_EI 367
#define T_Z80_HALT 368
#define T_Z80_INC 369
#define T_Z80_JP 370
#define T_Z80_JR 371
#define T_Z80_LD 372
#define T_Z80_LDI 373
#define T_Z80_LDD 374
#define T_Z80_LDIO 375
#define T_Z80_NOP 376
#define T_Z80_OR 377
#define T_Z80_POP 378
#define T_Z80_PUSH 379
#define T_Z80_RES 380
#define T_Z80_RET 381
#define T_Z80_RETI 382
#define T_Z80_RST 383
#define T_Z80_RL 384
#define T_Z80_RLA 385
#define T_Z80_RLC 386
#define T_Z80_RLCA 387
#define T_Z80_RR 388
#define T_Z80_RRA 389
#define T_Z80_RRC 390
#define T_Z80_RRCA 391
#define T_Z80_SBC 392
#define T_Z80_SCF 393
#define T_Z80_STOP 394
#define T_Z80_SLA 395
#define T_Z80_SRA 396
#define T_Z80_SRL 397
#define T_Z80_SUB 398
#define T_Z80_SWAP 399
#define T_Z80_XOR 400
#define T_TOKEN_A 401
#define T_TOKEN_B 402
#define T_TOKEN_C 403
#define T_TOKEN_D 404
#define T_TOKEN_E 405
#define T_TOKEN_H 406
#define T_TOKEN_L 407
#define T_MODE_AF 408
#define T_MODE_BC 409
#define T_MODE_BC_IND 410
#define T_MODE_DE 411
#define T_MODE_DE_IND 412
#define T_MODE_SP 413
#define T_MODE_SP_IND 414
#define T_MODE_C_IND 415
#define T_MODE_HL 416
#define T_MODE_HL_IND 417
#define T_MODE_HL_INDDEC 418
#define T_MODE_HL_INDINC 419
#define T_CC_NZ 420
#define T_CC_Z 421
#define T_CC_NC 422
#define YYERRCODE 256
typedef short YYINT;
static const YYINT yylhs[] = {                           -1,
    0,   19,   19,   20,   20,   20,   20,   20,   21,   21,
   21,   21,   27,   23,   26,   26,   26,   28,   25,   25,
   25,   25,   25,   25,   25,   24,   24,   24,   24,   24,
   24,   24,   24,   24,   24,   24,   24,   24,   24,   24,
   24,   24,   24,   24,   24,   24,   24,   24,   24,   24,
   24,   24,   24,   24,   66,   64,   65,   65,   67,   62,
   63,   60,   61,   57,   58,   56,   55,   35,   34,   52,
   51,   33,   32,   31,   49,   46,   47,   48,   72,   59,
   71,   71,   73,   43,   74,   74,   75,   44,   76,   76,
   77,   45,   78,   78,   79,   29,   30,   36,   53,   53,
   54,   54,   38,   39,   37,   40,   41,   42,    4,   68,
   68,   80,   80,   80,   69,   69,   81,   81,   70,   70,
   82,   82,    7,    5,    6,    1,    1,    1,    1,    1,
    1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
    1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
    1,    1,    1,   83,    1,    1,    1,    1,    1,    1,
    1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
    1,    3,    2,    2,    2,    2,    2,    2,    2,    2,
    2,    2,    2,    2,    2,    2,    2,    2,    2,    2,
    2,    2,    2,    2,    2,    2,    2,    2,    2,    2,
    2,    2,    2,    2,    2,    2,    2,    2,    2,    2,
   84,    2,    2,    2,    2,    2,    9,    9,    9,    9,
    9,   50,   50,   50,   50,   50,   50,   50,    8,    8,
    8,    8,    8,    8,    8,    8,    8,    8,    8,    8,
   22,   22,   22,   22,   22,   22,   22,   22,   22,   22,
   22,   22,   22,   22,   22,   22,   22,   22,   22,   22,
   22,   22,   22,   22,   22,   22,   22,   22,   22,   22,
   22,   22,   22,   22,   22,   22,   22,   22,   22,   22,
   22,   22,   22,   22,   22,   22,   85,   85,   86,   86,
   86,   86,   87,   87,   88,   89,   89,   90,   91,   91,
   92,   93,   94,   94,   95,   96,   97,   98,   98,   99,
   99,   99,   99,  100,  100,  103,  103,  103,  102,  102,
  102,  104,  104,  101,  101,  101,  101,  101,  101,  101,
  101,  137,  137,  137,  138,  138,  133,  133,  134,  135,
  139,  139,  140,  140,  140,  136,  136,  105,  106,  106,
  107,  108,  109,  110,  110,  111,  112,  113,  114,  115,
  116,  117,  118,  119,  120,  121,  121,  122,  123,  124,
  125,  126,  127,  128,  128,  129,  130,  130,   18,   17,
   17,   16,   16,   15,   15,  131,  132,  132,  141,  141,
  142,  142,  143,  143,  144,  144,  145,  145,  146,  146,
   14,   14,   14,   14,   10,   10,   10,   10,   10,   10,
   10,   10,   13,   13,   13,   13,   11,   11,   11,   11,
   12,   12,   12,   12,
};
static const YYINT yylen[] = {                            2,
    1,    0,    3,    1,    2,    2,    2,    1,    0,    1,
    2,    3,    0,    3,    0,    1,    3,    1,    1,    1,
    1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
    1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
    1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
    1,    1,    1,    1,    0,    3,    1,    3,    1,    1,
    1,    1,    1,    2,    2,    1,    2,    3,    3,    2,
    1,    3,    3,    3,    2,    2,    2,    2,    0,    3,
    1,    3,    1,    2,    1,    3,    1,    2,    1,    3,
    1,    2,    1,    3,    1,    3,    3,    2,    2,    6,
    4,    4,    2,    2,    2,    2,    1,    1,    1,    1,
    3,    0,    1,    1,    1,    3,    0,    1,    1,    3,
    0,    1,    1,    1,    1,    1,    1,    1,    2,    3,
    3,    3,    3,    3,    3,    3,    3,    3,    3,    3,
    3,    3,    3,    3,    3,    3,    3,    2,    2,    2,
    4,    4,    4,    0,    5,    4,    4,    4,    6,    6,
    4,    4,    4,    4,    4,    4,    6,    6,    6,    4,
    3,    1,    1,    1,    1,    2,    3,    3,    3,    3,
    3,    3,    3,    3,    3,    3,    3,    3,    3,    3,
    3,    3,    3,    3,    3,    2,    2,    2,    4,    4,
    4,    6,    6,    4,    4,    4,    4,    4,    4,    6,
    0,    5,    6,    6,    4,    3,    1,    8,    6,    4,
    4,    4,    7,    9,    9,   12,   14,   14,    1,    1,
    1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
    1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
    1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
    1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
    1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
    1,    1,    1,    1,    1,    1,    2,    2,    2,    2,
    2,    4,    2,    2,    4,    2,    4,    1,    2,    2,
    1,    1,    2,    2,    1,    1,    1,    2,    2,    2,
    4,    2,    2,    2,    4,    4,    4,    4,    4,    4,
    4,    4,    4,    1,    1,    1,    1,    1,    1,    1,
    1,    7,    5,    4,    4,    4,    4,    4,    4,    4,
    4,    4,    4,    4,    4,    4,    4,    1,    2,    2,
    2,    2,    4,    1,    2,    1,    2,    1,    2,    1,
    2,    1,    2,    1,    2,    2,    2,    1,    4,    2,
    2,    2,    1,    2,    2,    2,    2,    2,    3,    1,
    3,    1,    3,    1,    3,    1,    1,    4,    1,    4,
    1,    4,    1,    4,    1,    4,    1,    4,    1,    4,
    1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
    1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
    1,    1,    1,    1,
};
static const YYINT yydefred[] = {                         2,
    0,    0,    0,    0,    0,    8,   19,   20,   21,   22,
   23,   24,   25,    0,    0,    0,    0,    0,    0,    0,
    3,   13,    0,    0,    0,    0,    0,    0,  107,  108,
    0,    0,    0,    0,    0,    0,    0,    0,   71,    0,
    0,    0,    0,   66,    0,    0,   79,   62,   63,   60,
   61,   55,    0,    0,    0,    0,    0,  298,    0,  301,
  302,    0,  305,  306,  307,    0,    0,    0,    0,    0,
    0,    0,  348,    0,    0,    0,    0,    0,  356,    0,
    0,  358,    0,  360,    0,  362,    0,  364,    0,  368,
  373,    0,    0,    0,    0,    0,    0,    5,    6,    7,
   26,   27,   28,   29,   30,   31,   32,   33,   34,   35,
   36,   37,   38,   39,   40,   41,   42,   43,   44,   45,
   46,   47,   48,   49,   50,   51,   52,   53,   54,  241,
  242,  243,  244,  245,  246,  247,  248,  249,  250,  251,
  252,  253,  254,  255,  256,  257,  258,  259,  260,  261,
  262,  263,  264,  265,  266,  267,  268,  269,  270,  271,
  272,  273,  274,  275,  276,  277,  278,  279,  280,  281,
  282,  283,  284,  285,  286,  324,  325,  326,  327,  328,
  329,  330,  331,  174,  217,    0,    0,    0,    0,  211,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,  175,    0,   69,    0,   74,   73,   72,   68,
   12,    0,    0,    0,   98,    0,  103,    0,    0,   87,
   84,    0,   91,   88,    0,   95,   92,    0,  127,    0,
    0,    0,    0,  154,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,  126,    0,    0,  113,    0,   76,    0,   75,
    0,  118,  128,   77,    0,    0,   78,    0,    0,   70,
    0,   67,    0,   64,   65,    0,    0,    0,    0,  387,
  389,  391,  393,  395,  397,  399,  411,  384,  382,  287,
  288,    0,  405,  406,  407,  408,  409,  410,  417,  418,
    0,    0,  380,  289,  290,  291,  293,  294,    0,  404,
  401,  402,  403,  296,    0,  299,  300,    0,    0,  420,
  419,  303,  304,  412,  308,  309,  313,  312,  310,    0,
    0,  314,    0,    0,  421,    0,  422,    0,    0,    0,
  424,  423,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,  349,  350,  416,  413,  414,  415,  351,
  352,    0,  355,  365,  357,  359,  361,  363,  366,  367,
  370,  371,  372,  374,  375,  376,  377,  378,  176,  196,
  197,  198,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,   18,   14,    0,  386,    0,    0,    0,    0,
  129,  148,  149,  150,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,   83,   80,
    0,   59,   56,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,  187,  216,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,  193,
  194,  195,    0,  369,   86,   90,   94,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,  171,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,  145,  146,  147,  111,  116,  120,  229,  230,
  231,  232,  233,  234,  235,  236,  237,  238,  239,  240,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,  385,  383,  292,  381,  295,  297,  311,
  315,  346,  347,  335,  336,  339,    0,    0,  334,  379,
  343,  341,  342,  344,  345,  340,  337,  338,  316,  317,
  318,  319,  320,  321,  323,  322,  353,    0,  204,  205,
  206,  207,  208,  209,    0,    0,    0,  199,  200,  201,
    0,    0,    0,  215,    0,  220,  221,   17,    0,  153,
  161,  162,  163,  164,  165,  166,    0,    0,    0,  156,
  157,  158,  151,  152,    0,    0,  170,    0,    0,    0,
   82,   58,  388,  390,  394,  398,  392,  396,  400,  333,
    0,  212,    0,    0,    0,    0,    0,    0,    0,  155,
    0,    0,    0,    0,    0,    0,    0,    0,  100,    0,
  210,  202,  203,  213,  214,    0,  219,  167,  159,  160,
  168,  169,    0,    0,    0,  332,    0,    0,    0,    0,
  218,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,  226,    0,    0,  228,  227,
};
static const YYINT yydgoto[] = {                          1,
  265,  216,  217,  224,  298,  272,  342,  621,  213,  299,
  313,  355,  370,  325,  300,  301,  316,  356,    2,    4,
    5,   98,   99,  100,    6,  434,  222,  435,    7,    8,
    9,   10,   11,   12,   13,  101,  102,  103,  104,  105,
  106,  107,  108,  109,  110,  111,  112,  113,  114,  115,
  116,  117,  118,  119,  120,  121,  122,  123,  124,  125,
  126,  127,  128,  129,  493,  287,  494,  268,  274,  277,
  490,  286,  491,  231,  232,  234,  235,  237,  238,  269,
  275,  278,  445,  393,  130,  131,  132,  133,  134,  135,
  136,  137,  138,  139,  140,  141,  142,  143,  144,  145,
  146,  147,  148,  149,  150,  151,  152,  153,  154,  155,
  156,  157,  158,  159,  160,  161,  162,  163,  164,  165,
  166,  167,  168,  169,  170,  171,  172,  173,  174,  175,
  437,  334,  176,  177,  178,  179,  180,  181,  182,  183,
  303,  304,  305,  306,  307,  308,
};
static const YYINT yysindex[] = {                         0,
    0, -276,   99,   10, 2891,    0,    0,    0,    0,    0,
    0,    0,    0, 1485, 1485, -224, 1485, 1485, 1485,  -54,
    0,    0, 1485, -224, 1485, -224, 1485, 1485,    0,    0,
 -275, -261, -253, 1403, 1485, 1403, 1403, -224,    0, 1485,
 -224, 1485, -224,    0, -224, -224,    0,    0,    0,    0,
    0,    0, 1210, 1046, 1210, 1485,  947,    0, 1210,    0,
    0,  296,    0,    0,    0,  296,  348,  947,  -85, -284,
 -283,  -78,    0, 1210, -327, -327, 1485, -307,    0, 1403,
  377,    0,  377,    0,  377,    0,  377,    0, 1210,    0,
    0,  377,  377,  377, 1210,  377, 1210,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 1485, 1485, 1485, 1485,    0,
   16,   28,   35,   46,   71,   86,   91,  104,  106,  112,
  115,  116,  118,  122,  125,  128,  129,  131,  132, -206,
 1485, 2774,    0, 2774,    0, 2774,    0,    0,    0,    0,
    0, -192, 2774,  134,    0, 2774,    0, 2774, 2774,    0,
    0,  140,    0,    0,  142,    0,    0,  143,    0, 1403,
 1403, 1403, 1403,    0,  135,  148,  149,  153,  155,  162,
  165,  166,  167,  168,  172,  173,  175,  177,  212,  219,
  222,  224,    0, 1403, 2899,    0,    0,    0,  221,    0,
 2899,    0,    0,    0,  223, 2899,    0,  251,  252,    0,
  285,    0,  291,    0,    0, -132,    8,  228,  298,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,  134,    0,    0,    0,    0,    0,    0,    0,    0,
  134,  134,    0,    0,    0,    0,    0,    0,  134,    0,
    0,    0,    0,    0,  134,    0,    0,  299,  300,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,  134,
 2899,    0,  134,  134,    0,  134,    0,  134,  134,  134,
    0,    0, 1403,  134,  134,  134,  301,  134,  134,  134,
  134,  134,  134,    0,    0,    0,    0,    0,    0,    0,
    0,  134,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,  315, 1485, 1485, 1485, 1485, 1485, 1485, 1485,
 1485, 1485, 1485, 1485, 1485, -224, -224, -224, -224, -224,
 -224, -224,   31,  -33, 1485, 1485, 1485, 1485, 1485, 1485,
 1485, 1485, 1485, 1485, 1485, 1485, 1485, 1485, 1485, 1485,
 1485, 1485,    0,    0,  312,    0,  377, -275, -261, -253,
    0,    0,    0,    0,  317,   54, 1485, 1485, 1485, 1485,
 1485, 1485, 1485, 1485, 1485, 1485, 1485, 1485, 1403, 1403,
 -224, -224, -224, 1985, 1403, 1403, 1403, 1403, 1403, 1403,
 1403, 1403, 1403, 1403, 1403, 1403, 1403, 1403, 1403, 1403,
 1403, 1403, 1403, 1403, 1403, 1009, 1485, 1485,    0,    0,
  316,    0,    0,  318,   -8, 1259, 1210, 1403, -250,  377,
 1403, -321, -371, 1403, 1403, 1403, 1403, 1350, -278,   85,
  268,  996, -278, -285,  -42, -278, -287, -278, -281, -278,
  305,  377,   84, 2027, 2100, 2118, 2155, 2192, 2222, 2794,
 2812, 2844, 2240, 2264, 2287,  347,  355,  358,  351,  360,
  368,  369,    0,    0, 1153, 1153, 1153,  405,  405,  405,
  405,  405,  -52,  -52,  -77,  -77,  -77, -184, -184,    0,
    0,    0, -192,    0,    0,    0,    0,  114,  385, 2305,
 2355, 2373, 2392, 2410, 2429, 2862, 2881, 2918, 2477, 2501,
 2542, 2560, 2610,  383,  397,  401,    0, 1452, 1452, 1452,
  855,  855,  855,  855,  855,   75,   75,  -19,  -19,  -19,
 -178, -178,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
  -26,  399, 2774,    0, -132,    8,  403,  406,  407,  409,
  415,  416,  417,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 1403,   47,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,  418,    0,    0,
    0,    0,    0,    0, 1485, 1485, 1485,    0,    0,    0,
 -224, -224, 1485,    0, -224,    0,    0,    0,  420,    0,
    0,    0,    0,    0,    0,    0, 1485, 1485, 1485,    0,
    0,    0,    0,    0, -224, -224,    0, -143, 1485, 1485,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 1403,    0, 2647, 2666, 2684,  421,  422,  447,  451,    0,
 2714, 2738, 2756,  453,  454,  408,  423,  404,    0,  414,
    0,    0,    0,    0,    0, 1485,    0,    0,    0,    0,
    0,    0, 1485, 1485,  452,    0,  467,  439,  441,  236,
    0,  493,  494,  449,  279,  281, 1485,  471,  474,  476,
 1485, 1485,    0,  478,  479,    0,    0,
};
static const YYINT yyrindex[] = {                         0,
    0,  586,  779,    0,  557,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,  683,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    9,    0,   23,   25,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,  575,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,  613,
    0,  577,    0,  579,    0,   13,    0,    0,    0,    0,
    0,  582,  549,    0,    0,  584,    0,  587,  589,    0,
    0,  590,    0,    0,  598,    0,    0,  599,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,   17,    0, 1308,    0,  601,    0,
   26,    0,    0,    0,  602,   27,    0,  603,    0,    0,
  605,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,  608,    0,    0,    0,    0,    0,    0,    0,    0,
  609,  611,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
  612,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,  614,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    9,   23,   25,    0,    0,    0,    0,    0,
  619,    0,    0,  641,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,  133,  160, 2147,  495,  674,  767,
 1339, 1912,  170, 1849,   39, 1721, 1769, 1580, 1613,    0,
    0,    0,  582,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 2151, 2183, 2187,
 1953, 2007, 2060, 2092, 2139, 1859, 1902, 1795, 1814, 1827,
 1666, 1704,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
  645,    0,  646,  920,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,  648,    0,    0,    0,    0,    0,
    0,  649,  650,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,
};
static const YYINT yygindex[] = {                         0,
  361,  126,  -18,  -30,   21,  -55,  156,    0,    5,   98,
  -59,  150,  588,  -53,   53,  717,    0,  -67,    0,    0,
    0,    0,    0,    0,    0,  100,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,   40,    0,    0,  184,  185,  198,
   45,    0,    0,  247,    0,  249,    0,  254,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 2990,   50,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,
};
#define YYTABLESIZE 3362
static const YYINT yytable[] = {                        218,
  219,  324,  333,  221,  362,  353,  336,  544,  357,  357,
  357,  339,  353,  340,  343,  357,  270,  708,  112,   21,
  215,  280,  172,  282,  373,  319,  124,    3,  225,  230,
  227,  264,  117,  185,  121,  125,  122,  631,  267,  632,
  273,  273,  279,  233,  633,  281,  372,  283,  189,  284,
  285,  236,  112,  172,  266,  394,  172,  273,  273,  273,
  124,  273,  413,  273,  709,  433,  117,  395,  121,  125,
  122,  273,  273,  205,  396,  207,  208,  209,  273,  189,
  366,  367,  189,  368,  273,  397,  627,  628,  369,  629,
  430,  431,  432,  273,  630,  320,  480,  481,  482,  273,
  374,  273,  302,  302,  302,  172,  314,  317,  302,  124,
  398,  326,  321,  322,  323,  290,  290,  290,  125,  359,
  361,  363,  290,  302,  264,  399,  364,  657,  660,  661,
  400,  189,  358,  360,  663,  664,  736,  737,  302,  212,
  214,  379,  177,  401,  302,  402,  302,  384,  223,  387,
  226,  403,  228,  229,  404,  405,   20,  406,  309,  332,
  310,  407,  330,  335,  408,  331,  354,  409,  410,  178,
  411,  412,  489,  177,  446,  648,  177,  436,  375,  185,
  376,  223,  377,  438,  378,  439,  440,  447,  448,  381,
  382,  383,  449,  386,  450,  428,  429,  430,  431,  432,
  178,  451,  223,  178,  452,  453,  454,  455,  328,  329,
  185,  456,  457,  185,  458,  357,  459,  425,  426,  427,
  428,  429,  430,  431,  432,  177,  415,  416,  417,  418,
  419,  420,  421,  422,  423,  424,  425,  426,  427,  428,
  429,  430,  431,  432,  273,  273,  273,  273,  239,  185,
  240,  460,  178,  478,  479,  480,  481,  482,  461,  241,
  242,  462,  185,  463,  483,  492,  484,  495,  273,  243,
  244,  245,  220,  246,  247,  248,  249,  250,  251,  252,
  253,  254,  255,  256,  257,  258,  259,  260,  261,  205,
  262,  207,  208,  209,  485,  486,  263,  511,  189,  189,
  189,  189,  189,  189,  189,  189,  189,  189,  189,  189,
  189,  389,  390,  391,  392,  290,  291,  292,  293,  294,
  295,  296,  290,  344,  345,  346,  347,  348,  487,  349,
  350,  297,  351,  352,  488,  543,  414,  496,  502,  503,
  515,  239,  185,  240,  475,  476,  477,  478,  479,  480,
  481,  482,  241,  242,  523,  563,  568,  273,  569,  625,
  650,  626,  243,  244,  245,  627,  246,  247,  248,  249,
  250,  251,  252,  253,  254,  255,  256,  257,  258,  259,
  260,  261,  205,  262,  207,  208,  209,  264,  668,  263,
  681,  684,  177,  177,  177,  353,  271,  276,  682,  627,
  628,  683,  629,  685,   14,   15,   16,  630,  686,  687,
  536,  537,  538,  539,  540,  541,  542,  271,  689,  178,
  178,  178,   17,   18,   19,  690,  705,  271,  341,  185,
  185,  185,  185,  185,  185,  185,  185,  185,  185,  637,
  706,  707,  710,  713,  655,  639,  714,  715,  640,  716,
  642,  643,  645,  666,  649,  717,  718,  719,  722,  721,
  730,  744,  745,  273,  273,  584,  585,  586,  622,  273,
  273,  273,  273,  273,  273,  273,  273,  273,  273,  273,
  273,  273,  273,  273,  273,  273,  273,  267,  273,  273,
  746,  747,  624,  751,  752,  760,  755,  647,  753,  273,
  273,  273,  273,  266,  180,  273,  756,  761,  273,  273,
  273,  273,  273,  754,  273,  764,  273,  634,  636,  524,
  525,  526,  527,  528,  529,  530,  531,  532,  533,  534,
  535,  762,  652,  763,  564,  180,  765,  766,  180,  767,
  545,  546,  547,  548,  549,  550,  551,  552,  553,  554,
  555,  556,  557,  558,  559,  560,  561,  562,  646,  768,
  769,  771,  656,  658,  772,  659,    4,  662,  773,  665,
  776,  777,  570,  571,  572,  573,  574,  575,  576,  577,
  578,  579,  580,  581,  354,    1,   96,  180,   97,  328,
  329,   15,  109,  105,  635,    9,  104,  638,  106,   85,
  441,  442,  443,  444,  239,  185,  240,   89,   93,  653,
  110,  115,  119,  623,   99,  241,  242,  412,  420,  667,
  419,  123,  173,   16,  464,  243,  244,  245,   81,  246,
  247,  248,  249,  250,  251,  252,  253,  254,  255,  256,
  257,  258,  259,  260,  261,  205,  262,  207,  208,  209,
   57,  273,  263,  173,  222,  102,  173,  223,  225,  224,
  641,  654,  688,  371,  728,  712,  606,  720,  607,  711,
  328,  329,  423,  424,  425,  426,  427,  428,  429,  430,
  431,  432,  608,  181,  565,  726,  727,  566,    0,  729,
  738,  739,   11,  567,    0,    0,  290,  291,  292,  293,
  294,  295,  296,    0,  309,  173,  310,    0,  330,  734,
  735,  331,  297,  271,  181,    0,    0,  181,    0,    0,
    0,    0,    0,    0,    0,  273,    0,  757,    0,    0,
    0,    0,    0,    0,  758,  759,    0,    0,    0,    0,
    0,  740,    0,    0,    0,    0,    0,    0,  770,    0,
  320,    0,  774,  775,  180,  180,  180,  180,  180,  180,
  180,  180,    0,  337,  338,    0,  181,  321,  322,  323,
  315,  318,    0,    0,    0,  327,  182,  290,  291,  292,
  293,  294,  295,  296,    0,    0,    0,    0,   10,    0,
  365,    0,    0,  297,    0,    0,    0,    0,    0,    0,
  723,  724,  725,    0,    0,  380,    0,  182,    0,    0,
  182,  385,    0,  388,    0,    0,    0,    0,    0,  582,
  583,    0,  731,  732,  733,  588,  589,  590,  591,  592,
  593,  594,  595,  596,  597,  598,  599,  600,  601,  602,
  603,  604,  605,    0,  271,  276,    0,    0,    0,    0,
    0,    0,    0,    0,    0,  582,  583,    0,    0,  182,
    0,  271,    0,    0,  271,  341,  271,  271,  271,    0,
  271,    0,  173,  173,  173,  173,  173,  173,  173,  173,
  173,    0,  173,  173,  173,  173,  173,  173,  173,  173,
    9,    0,    9,    0,    9,    9,    9,    9,    9,    9,
    9,    9,    9,    9,    9,    9,    9,    9,    9,    0,
    0,    0,    0,    0,    9,    9,    9,    9,    9,    9,
    0,    9,    9,    9,    9,    9,    9,    9,    9,  101,
    0,    0,    0,  181,  181,  181,  181,  181,  181,  181,
  181,    9,    9,    9,    9,    9,    9,    9,    9,    9,
    9,    9,    9,    9,    9,    9,    9,    9,    9,    9,
    9,    9,    9,    9,    9,    9,    9,    9,    9,    9,
    9,    9,    9,    9,    9,    9,    9,    9,    9,    9,
    9,    9,    9,    9,    9,    9,  264,   11,    0,   11,
    0,   11,   11,   11,   11,   11,   11,   11,   11,   11,
   11,   11,   11,   11,   11,   11,    0,    0,    0,    0,
    0,   11,   11,   11,   11,   11,   11,    0,   11,   11,
   11,   11,   11,   11,   11,   11,  182,  182,  182,  182,
  182,  182,  182,  182,    0,  264,    0,    0,   11,   11,
   11,   11,   11,   11,   11,   11,   11,   11,   11,   11,
   11,   11,   11,   11,   11,   11,   11,   11,   11,   11,
   11,   11,   11,   11,   11,   11,   11,   11,   11,   11,
   11,   11,   11,   11,   11,   11,   11,   11,   11,   11,
   11,   11,   11,   10,    0,  264,  353,   10,   10,   10,
   10,   10,   10,   10,   10,   10,   10,   10,   10,   10,
   10,   10,    0,    0,    0,    0,    0,   10,   10,   10,
   10,   10,   10,    0,   10,   10,   10,   10,   10,   10,
   10,   10,  473,  474,  475,  476,  477,  478,  479,  480,
  481,  482,    0,    0,   10,   10,   10,   10,   10,   10,
   10,   10,   10,   10,   10,   10,   10,   10,   10,   10,
   10,   10,   10,   10,   10,   10,   10,   10,   10,   10,
   10,   10,   10,   10,   10,   10,   10,   10,   10,   10,
   10,   10,   10,   10,   10,   10,   10,   10,   10,  175,
  175,  175,  175,  175,  175,  175,  175,  175,  175,  175,
  175,  175,  175,  175,  175,  175,  175,    0,    0,    0,
    0,    0,    0,  239,  185,  240,    0,    0,    0,    0,
    0,    0,    0,    0,  241,  242,    0,    0,    0,    0,
    0,    0,    0,    0,  243,  244,  245,    0,  246,  247,
  248,  249,  250,  251,  252,  253,  254,  255,  256,  257,
  258,  259,  260,  261,  205,  262,  207,  208,  209,  264,
    0,  263,  239,  185,  240,    0,    0,    0,    0,    0,
    0,    0,    0,  241,  242,    0,    0,    0,    0,    0,
    0,    0,    0,  243,  244,  245,    0,  246,  247,  248,
  249,  250,  251,  252,  253,  254,  255,  256,  257,  288,
  289,  260,  261,  205,  262,  207,  208,  209,  264,    0,
  263,    0,  239,  185,  240,    0,    0,    0,    0,    0,
    0,    0,    0,  241,  242,    0,    0,  114,    0,    0,
    0,    0,    0,  243,  244,  245,    0,  246,  247,  248,
  249,  250,  251,  252,  253,  254,  255,  256,  257,  288,
  289,  260,  261,  205,  262,  207,  208,  209,  183,  320,
  263,  114,  609,  610,  611,  612,  613,  614,  615,  616,
  617,  618,  619,  620,    0,    0,  321,  322,  323,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,  183,
    0,    0,  183,    0,    0,    0,    0,    0,    0,  264,
    0,    0,    0,    0,    0,    0,  290,  291,  292,  293,
  294,  295,  296,    0,    0,  345,    0,  347,    0,    0,
  651,    0,  297,  351,  352,  418,  419,  420,  421,  422,
  423,  424,  425,  426,  427,  428,  429,  430,  431,  432,
    0,  183,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,  264,    0,    0,    0,  290,  291,  292,  293,
  294,  295,  296,    0,  309,    0,  310,    0,  311,    0,
    0,  312,  297,    0,    0,    0,  239,  185,  240,    0,
    0,    0,    0,    0,    0,    0,    0,  241,  242,    0,
    0,    0,    0,    0,    0,    0,    0,  243,  244,  245,
    0,  246,  247,  248,  249,  250,  251,  252,  253,  254,
  255,  256,  257,  288,  289,  260,  261,  205,  262,  207,
  208,  209,    0,    0,  263,  239,  185,  240,    0,    0,
    0,    0,    0,    0,  211,    0,  241,  242,    0,    0,
    0,    0,    0,    0,    0,    0,  243,  244,  245,    0,
  246,  247,  248,  249,  250,  251,  252,  253,  254,  255,
  256,  257,  258,  259,  260,  261,  205,  262,  207,  208,
  209,    0,    0,  263,    0,    0,    0,  128,  128,  128,
  128,  128,  128,  128,  128,  128,  128,  128,  128,  128,
  128,  128,  128,  128,  128,    0,    0,    0,    0,  191,
    0,    0,    0,    0,    0,    0,    0,    0,  183,  183,
  183,  183,  183,  183,  183,  183,  239,  185,  240,    0,
  290,  291,  292,  293,  294,  295,  296,  241,  242,    0,
  191,    0,  192,  191,    0,    0,  297,  243,  244,  245,
    0,  246,  247,  248,  249,  250,  251,  252,  253,  254,
  255,  256,  257,  258,  259,  260,  261,  205,  262,  207,
  208,  209,    0,  192,  263,    0,  192,    0,    0,  239,
  185,  240,    0,    0,    0,    0,    0,  631,    0,  632,
  241,  242,  191,    0,  633,  143,    0,    0,    0,    0,
  243,  244,  245,    0,  246,  247,  248,  249,  250,  251,
  252,  253,  254,  255,  256,  257,  258,  259,  260,  261,
  205,  262,  207,  208,  209,  192,  143,  263,    0,  143,
    0,    0,    0,  144,  468,  469,  470,  471,  472,  473,
  474,  475,  476,  477,  478,  479,  480,  481,  482,    0,
  188,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,  184,  185,  186,  144,    0,    0,  144,    0,    0,
    0,    0,  187,  188,    0,    0,    0,    0,  143,    0,
    0,  188,  189,  190,  188,  644,  191,  192,  193,  194,
  195,  196,  197,  198,  199,  200,  201,  202,  190,    0,
  203,  204,  205,  206,  207,  208,  209,    0,    0,  210,
    0,    0,    0,    0,    0,    0,  144,    0,    0,    0,
    0,    0,    0,    0,  141,    0,    0,    0,    0,  190,
    0,    0,  190,  188,    0,    0,    0,    0,    0,    0,
    0,    0,    0,  140,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,  141,  142,    0,  141,  191,
  191,  191,  191,  191,  191,  191,  191,  191,  191,  191,
  191,  191,  191,  191,  140,    0,    0,  140,  186,    0,
    0,  190,    0,    0,    0,    0,    0,  142,  138,    0,
  142,    0,  192,  192,  192,  192,  192,  192,  192,  192,
  192,  192,  192,  192,  192,  192,  192,  141,    0,  186,
    0,    0,  186,    0,    0,    0,    0,    0,    0,  138,
    0,    0,  138,    0,    0,    0,  140,    0,    0,    0,
    0,  139,    0,    0,    0,    0,    0,    0,    0,  142,
    0,  184,    0,    0,    0,  143,  143,  143,  143,  143,
  143,  143,  143,  143,  143,  143,  143,  143,  143,  143,
    0,  186,  139,    0,    0,  139,    0,    0,    0,    0,
    0,  138,  184,    0,    0,  184,    0,    0,    0,    0,
    0,    0,  133,  144,  144,  144,  144,  144,  144,  144,
  144,  144,  144,  144,  144,  144,  144,  144,    0,    0,
  188,  188,  188,  188,  188,  188,  188,  188,  188,  188,
  188,  188,  188,  133,  139,    0,  133,    0,    0,    0,
    0,    0,    0,    0,  184,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,  134,    0,    0,    0,
    0,    0,    0,    0,    0,  587,    0,    0,  190,  190,
  190,  190,  190,  190,  190,  190,  190,  190,  190,  190,
  190,    0,    0,    0,    0,  133,    0,  134,    0,    0,
  134,    0,    0,    0,  141,  141,  141,  141,  141,  141,
  141,  141,  141,  141,  141,  141,  141,  669,    0,  135,
    0,    0,    0,  140,  140,  140,  140,  140,  140,  140,
  140,  140,  140,  140,  140,  140,  142,  142,  142,  142,
  142,  142,  142,  142,  142,  142,  142,  142,  142,  134,
  135,  136,    0,  135,    0,    0,    0,    0,  186,  186,
  186,  186,  186,  186,  186,  186,  186,  186,  138,  138,
  138,  138,  138,  138,  138,  138,  138,  138,    0,    0,
    0,    0,  136,    0,    0,  136,    0,    0,    0,    0,
  670,    0,    0,    0,    0,    0,    0,    0,  137,    0,
    0,    0,  135,    0,    0,    0,  179,    0,  671,    0,
  130,  139,  139,  139,  139,  139,  139,  139,  139,  139,
  139,  184,  184,  184,  184,  184,  184,  184,  184,  137,
    0,    0,  137,    0,  136,    0,    0,  179,    0,    0,
  179,  130,  131,    0,  130,  672,  132,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,  133,  133,  133,  133,  133,  133,  133,  133,
    0,    0,    0,  131,    0,    0,  131,  132,    0,    0,
  132,  137,  673,    0,    0,    0,    0,    0,    0,  179,
    0,    0,    0,  130,  465,  466,  467,  468,  469,  470,
  471,  472,  473,  474,  475,  476,  477,  478,  479,  480,
  481,  482,  674,    0,    0,    0,  134,  134,  134,  134,
  134,  134,  134,  134,    0,  131,    0,    0,    0,  132,
  678,    0,    0,    0,    0,    0,  415,  416,  417,  418,
  419,  420,  421,  422,  423,  424,  425,  426,  427,  428,
  429,  430,  431,  432,  679,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,  135,
  135,  135,  135,  135,  135,  135,  135,  680,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,  691,    0,    0,    0,    0,
    0,  136,  136,  136,  136,  136,  136,  136,  136,  415,
  416,  417,  418,  419,  420,  421,  422,  423,  424,  425,
  426,  427,  428,  429,  430,  431,  432,  415,  416,  417,
  418,  419,  420,  421,  422,  423,  424,  425,  426,  427,
  428,  429,  430,  431,  432,  692,    0,    0,  137,  137,
  137,  137,  137,  137,  137,  137,  179,  179,  179,    0,
  130,  130,  130,  693,  415,  416,  417,  418,  419,  420,
  421,  422,  423,  424,  425,  426,  427,  428,  429,  430,
  431,  432,  694,    0,    0,    0,    0,    0,    0,    0,
    0,    0,  131,  131,  131,    0,  132,  132,  132,    0,
  695,  415,  416,  417,  418,  419,  420,  421,  422,  423,
  424,  425,  426,  427,  428,  429,  430,  431,  432,  696,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,  415,  416,  417,  418,  419,  420,  421,  422,  423,
  424,  425,  426,  427,  428,  429,  430,  431,  432,  415,
  416,  417,  418,  419,  420,  421,  422,  423,  424,  425,
  426,  427,  428,  429,  430,  431,  432,  700,    0,    0,
    0,    0,    0,  415,  416,  417,  418,  419,  420,  421,
  422,  423,  424,  425,  426,  427,  428,  429,  430,  431,
  432,  701,    0,    0,    0,    0,  415,  416,  417,  418,
  419,  420,  421,  422,  423,  424,  425,  426,  427,  428,
  429,  430,  431,  432,  415,  416,  417,  418,  419,  420,
  421,  422,  423,  424,  425,  426,  427,  428,  429,  430,
  431,  432,  702,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
  703,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,  415,  416,  417,  418,  419,  420,
  421,  422,  423,  424,  425,  426,  427,  428,  429,  430,
  431,  432,  415,  416,  417,  418,  419,  420,  421,  422,
  423,  424,  425,  426,  427,  428,  429,  430,  431,  432,
  704,  415,  416,  417,  418,  419,  420,  421,  422,  423,
  424,  425,  426,  427,  428,  429,  430,  431,  432,  415,
  416,  417,  418,  419,  420,  421,  422,  423,  424,  425,
  426,  427,  428,  429,  430,  431,  432,  741,  415,  416,
  417,  418,  419,  420,  421,  422,  423,  424,  425,  426,
  427,  428,  429,  430,  431,  432,  742,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,  743,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,  415,  416,  417,  418,
  419,  420,  421,  422,  423,  424,  425,  426,  427,  428,
  429,  430,  431,  432,  748,    0,    0,    0,    0,    0,
  415,  416,  417,  418,  419,  420,  421,  422,  423,  424,
  425,  426,  427,  428,  429,  430,  431,  432,  749,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,  750,    0,    0,    0,
    0,  415,  416,  417,  418,  419,  420,  421,  422,  423,
  424,  425,  426,  427,  428,  429,  430,  431,  432,  465,
  466,  467,  468,  469,  470,  471,  472,  473,  474,  475,
  476,  477,  478,  479,  480,  481,  482,  675,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,  676,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,  465,
  466,  467,  468,  469,  470,  471,  472,  473,  474,  475,
  476,  477,  478,  479,  480,  481,  482,  677,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,  697,  415,  416,  417,  418,
  419,  420,  421,  422,  423,  424,  425,  426,  427,  428,
  429,  430,  431,  432,  698,  415,  416,  417,  418,  419,
  420,  421,  422,  423,  424,  425,  426,  427,  428,  429,
  430,  431,  432,  415,  416,  417,  418,  419,  420,  421,
  422,  423,  424,  425,  426,  427,  428,  429,  430,  431,
  432,  699,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,  415,  416,  417,  418,  419,  420,  421,
  422,  423,  424,  425,  426,  427,  428,  429,  430,  431,
  432,    0,    0,    0,    0,    0,    0,  415,  416,  417,
  418,  419,  420,  421,  422,  423,  424,  425,  426,  427,
  428,  429,  430,  431,  432,  415,  416,  417,  418,  419,
  420,  421,  422,  423,  424,  425,  426,  427,  428,  429,
  430,  431,  432,  415,  416,  417,  418,  419,  420,  421,
  422,  423,  424,  425,  426,  427,  428,  429,  430,  431,
  432,    0,    0,  415,  416,  417,  418,  419,  420,  421,
  422,  423,  424,  425,  426,  427,  428,  429,  430,  431,
  432,  415,  416,  417,  418,  419,  420,  421,  422,  423,
  424,  425,  426,  427,  428,  429,  430,  431,  432,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,  415,  416,  417,  418,  419,  420,  421,
  422,  423,  424,  425,  426,  427,  428,  429,  430,  431,
  432,  415,  416,  417,  418,  419,  420,  421,  422,  423,
  424,  425,  426,  427,  428,  429,  430,  431,  432,    0,
  415,  416,  417,  418,  419,  420,  421,  422,  423,  424,
  425,  426,  427,  428,  429,  430,  431,  432,  465,  466,
  467,  468,  469,  470,  471,  472,  473,  474,  475,  476,
  477,  478,  479,  480,  481,  482,    0,  415,  416,  417,
  418,  419,  420,  421,  422,  423,  424,  425,  426,  427,
  428,  429,  430,  431,  432,   22,    0,   23,    0,   24,
   25,   26,   27,   28,   29,   30,   31,   32,   33,   34,
   35,   36,   37,   38,    0,    0,    0,    0,    0,   39,
   40,   41,   42,   43,   44,    0,   45,   46,   47,   48,
   49,   50,   51,   52,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,   53,   54,   55,   56,
   57,   58,   59,   60,   61,   62,   63,   64,   65,   66,
   67,   68,   69,   70,   71,   72,   73,   74,   75,   76,
   77,   78,   79,   80,   81,   82,   83,   84,   85,   86,
   87,   88,   89,   90,   91,   92,   93,   94,   95,   96,
   97,  497,    0,    0,    0,    0,    0,    0,    0,    0,
  498,  499,    0,    0,    0,    0,    0,    0,  500,    0,
    0,    0,    0,    0,  501,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,  504,
    0,    0,  505,  506,    0,  507,    0,  508,  509,  510,
    0,    0,    0,  512,  513,  514,    0,  516,  517,  518,
  519,  520,  521,    0,    0,    0,    0,    0,    0,    0,
    0,  522,
};
static const YYINT yycheck[] = {                         18,
   19,   57,   62,   58,   72,   91,   66,   41,  294,  294,
  294,   67,   91,   67,   68,  294,   35,   44,   10,   10,
   16,   40,   10,   42,   78,   56,   10,  304,   24,  305,
   26,   40,   10,  258,   10,   10,   10,  409,   34,  411,
   36,   37,   38,  305,  416,   41,   77,   43,   10,   45,
   46,  305,   44,   41,   34,   40,   44,   53,   54,   55,
   44,   57,  269,   59,   91,  258,   44,   40,   44,   44,
   44,   67,   68,  298,   40,  300,  301,  302,   74,   41,
  408,  409,   44,  411,   80,   40,  408,  409,  416,  411,
  275,  276,  277,   89,  416,  403,  275,  276,  277,   95,
   80,   97,   53,   54,   55,   93,   54,   55,   59,   93,
   40,   59,  420,  421,  422,  401,  401,  401,   93,   70,
   71,   72,  401,   74,   40,   40,   74,  413,  416,  417,
   40,   93,  417,  417,  416,  417,  280,  281,   89,   14,
   15,   89,   10,   40,   95,   40,   97,   95,   23,   97,
   25,   40,   27,   28,   40,   40,   58,   40,  409,   62,
  411,   40,  413,   66,   40,  416,   69,   40,   40,   10,
   40,   40,  305,   41,   40,   91,   44,   44,   81,   10,
   83,   56,   85,   44,   87,   44,   44,   40,   40,   92,
   93,   94,   40,   96,   40,  273,  274,  275,  276,  277,
   41,   40,   77,   44,   40,   40,   40,   40,  294,  295,
   41,   40,   40,   44,   40,  294,   40,  270,  271,  272,
  273,  274,  275,  276,  277,   93,  260,  261,  262,  263,
  264,  265,  266,  267,  268,  269,  270,  271,  272,  273,
  274,  275,  276,  277,  240,  241,  242,  243,  257,  258,
  259,   40,   93,  273,  274,  275,  276,  277,   40,  268,
  269,   40,   93,   40,   44,  258,   44,   40,  264,  278,
  279,  280,  327,  282,  283,  284,  285,  286,  287,  288,
  289,  290,  291,  292,  293,  294,  295,  296,  297,  298,
  299,  300,  301,  302,   44,   44,  305,  353,  260,  261,
  262,  263,  264,  265,  266,  267,  268,  269,  270,  271,
  272,  186,  187,  188,  189,  401,  402,  403,  404,  405,
  406,  407,  401,  409,  410,  411,  412,  413,   44,  415,
  416,  417,  418,  419,   44,  305,  211,   40,   40,   40,
   40,  257,  258,  259,  270,  271,  272,  273,  274,  275,
  276,  277,  268,  269,   40,   44,   40,  353,  305,   44,
   93,   44,  278,  279,  280,  408,  282,  283,  284,  285,
  286,  287,  288,  289,  290,  291,  292,  293,  294,  295,
  296,  297,  298,  299,  300,  301,  302,   40,  305,  305,
   44,   41,  260,  261,  262,   91,   36,   37,   44,  408,
  409,   44,  411,   44,  306,  307,  308,  416,   41,   41,
  406,  407,  408,  409,  410,  411,  412,   57,  305,  260,
  261,  262,  324,  325,  326,   41,   44,   67,   68,  260,
  261,  262,  263,  264,  265,  266,  267,  268,  269,  499,
   44,   41,   44,   41,  512,  501,   41,   41,  504,   41,
  506,  507,  508,  521,  510,   41,   41,   41,   41,  413,
   41,   41,   41,  459,  460,  461,  462,  463,  487,  465,
  466,  467,  468,  469,  470,  471,  472,  473,  474,  475,
  476,  477,  478,  479,  480,  481,  482,  483,  484,  485,
   44,   41,  488,   41,   41,   44,   93,  413,   91,  495,
  496,  497,  498,  483,   10,  501,   93,   41,  504,  505,
  506,  507,  508,   91,  510,  280,  512,  497,  498,  394,
  395,  396,  397,  398,  399,  400,  401,  402,  403,  404,
  405,   93,  512,   93,  437,   41,   44,   44,   44,   91,
  415,  416,  417,  418,  419,  420,  421,  422,  423,  424,
  425,  426,  427,  428,  429,  430,  431,  432,  509,  281,
  280,   91,  513,  514,   91,  516,   10,  518,   93,  520,
   93,   93,  447,  448,  449,  450,  451,  452,  453,  454,
  455,  456,  457,  458,   10,    0,   10,   93,   10,  294,
  295,   10,   44,   10,  497,   10,   10,  500,   10,   10,
  240,  241,  242,  243,  257,  258,  259,   10,   10,  512,
   10,   10,   10,  488,   10,  268,  269,   10,   10,  522,
   10,   10,   10,   10,  264,  278,  279,  280,   10,  282,
  283,  284,  285,  286,  287,  288,  289,  290,  291,  292,
  293,  294,  295,  296,  297,  298,  299,  300,  301,  302,
   10,  647,  305,   41,   10,   10,   44,   10,   10,   10,
  505,  512,  563,   76,  683,  626,  483,  647,  484,  625,
  294,  295,  268,  269,  270,  271,  272,  273,  274,  275,
  276,  277,  485,   10,  438,  681,  682,  439,   -1,  685,
  709,  710,   10,  440,   -1,   -1,  401,  402,  403,  404,
  405,  406,  407,   -1,  409,   93,  411,   -1,  413,  705,
  706,  416,  417,  353,   41,   -1,   -1,   44,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  721,   -1,  746,   -1,   -1,
   -1,   -1,   -1,   -1,  753,  754,   -1,   -1,   -1,   -1,
   -1,  721,   -1,   -1,   -1,   -1,   -1,   -1,  767,   -1,
  403,   -1,  771,  772,  260,  261,  262,  263,  264,  265,
  266,  267,   -1,  416,  417,   -1,   93,  420,  421,  422,
   54,   55,   -1,   -1,   -1,   59,   10,  401,  402,  403,
  404,  405,  406,  407,   -1,   -1,   -1,   -1,   10,   -1,
   74,   -1,   -1,  417,   -1,   -1,   -1,   -1,   -1,   -1,
  675,  676,  677,   -1,   -1,   89,   -1,   41,   -1,   -1,
   44,   95,   -1,   97,   -1,   -1,   -1,   -1,   -1,  459,
  460,   -1,  697,  698,  699,  465,  466,  467,  468,  469,
  470,  471,  472,  473,  474,  475,  476,  477,  478,  479,
  480,  481,  482,   -1,  484,  485,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  495,  496,   -1,   -1,   93,
   -1,  501,   -1,   -1,  504,  505,  506,  507,  508,   -1,
  510,   -1,  260,  261,  262,  263,  264,  265,  266,  267,
  268,   -1,  270,  271,  272,  273,  274,  275,  276,  277,
  305,   -1,  307,   -1,  309,  310,  311,  312,  313,  314,
  315,  316,  317,  318,  319,  320,  321,  322,  323,   -1,
   -1,   -1,   -1,   -1,  329,  330,  331,  332,  333,  334,
   -1,  336,  337,  338,  339,  340,  341,  342,  343,   10,
   -1,   -1,   -1,  260,  261,  262,  263,  264,  265,  266,
  267,  356,  357,  358,  359,  360,  361,  362,  363,  364,
  365,  366,  367,  368,  369,  370,  371,  372,  373,  374,
  375,  376,  377,  378,  379,  380,  381,  382,  383,  384,
  385,  386,  387,  388,  389,  390,  391,  392,  393,  394,
  395,  396,  397,  398,  399,  400,   40,  305,   -1,  307,
   -1,  309,  310,  311,  312,  313,  314,  315,  316,  317,
  318,  319,  320,  321,  322,  323,   -1,   -1,   -1,   -1,
   -1,  329,  330,  331,  332,  333,  334,   -1,  336,  337,
  338,  339,  340,  341,  342,  343,  260,  261,  262,  263,
  264,  265,  266,  267,   -1,   40,   -1,   -1,  356,  357,
  358,  359,  360,  361,  362,  363,  364,  365,  366,  367,
  368,  369,  370,  371,  372,  373,  374,  375,  376,  377,
  378,  379,  380,  381,  382,  383,  384,  385,  386,  387,
  388,  389,  390,  391,  392,  393,  394,  395,  396,  397,
  398,  399,  400,  305,   -1,   40,   91,  309,  310,  311,
  312,  313,  314,  315,  316,  317,  318,  319,  320,  321,
  322,  323,   -1,   -1,   -1,   -1,   -1,  329,  330,  331,
  332,  333,  334,   -1,  336,  337,  338,  339,  340,  341,
  342,  343,  268,  269,  270,  271,  272,  273,  274,  275,
  276,  277,   -1,   -1,  356,  357,  358,  359,  360,  361,
  362,  363,  364,  365,  366,  367,  368,  369,  370,  371,
  372,  373,  374,  375,  376,  377,  378,  379,  380,  381,
  382,  383,  384,  385,  386,  387,  388,  389,  390,  391,
  392,  393,  394,  395,  396,  397,  398,  399,  400,  260,
  261,  262,  263,  264,  265,  266,  267,  268,  269,  270,
  271,  272,  273,  274,  275,  276,  277,   -1,   -1,   -1,
   -1,   -1,   -1,  257,  258,  259,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  268,  269,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  278,  279,  280,   -1,  282,  283,
  284,  285,  286,  287,  288,  289,  290,  291,  292,  293,
  294,  295,  296,  297,  298,  299,  300,  301,  302,   40,
   -1,  305,  257,  258,  259,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  268,  269,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  278,  279,  280,   -1,  282,  283,  284,
  285,  286,  287,  288,  289,  290,  291,  292,  293,  294,
  295,  296,  297,  298,  299,  300,  301,  302,   40,   -1,
  305,   -1,  257,  258,  259,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  268,  269,   -1,   -1,   10,   -1,   -1,
   -1,   -1,   -1,  278,  279,  280,   -1,  282,  283,  284,
  285,  286,  287,  288,  289,  290,  291,  292,  293,  294,
  295,  296,  297,  298,  299,  300,  301,  302,   10,  403,
  305,   44,  344,  345,  346,  347,  348,  349,  350,  351,
  352,  353,  354,  355,   -1,   -1,  420,  421,  422,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   41,
   -1,   -1,   44,   -1,   -1,   -1,   -1,   -1,   -1,   40,
   -1,   -1,   -1,   -1,   -1,   -1,  401,  402,  403,  404,
  405,  406,  407,   -1,   -1,  410,   -1,  412,   -1,   -1,
  415,   -1,  417,  418,  419,  263,  264,  265,  266,  267,
  268,  269,  270,  271,  272,  273,  274,  275,  276,  277,
   -1,   93,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   40,   -1,   -1,   -1,  401,  402,  403,  404,
  405,  406,  407,   -1,  409,   -1,  411,   -1,  413,   -1,
   -1,  416,  417,   -1,   -1,   -1,  257,  258,  259,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  268,  269,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  278,  279,  280,
   -1,  282,  283,  284,  285,  286,  287,  288,  289,  290,
  291,  292,  293,  294,  295,  296,  297,  298,  299,  300,
  301,  302,   -1,   -1,  305,  257,  258,  259,   -1,   -1,
   -1,   -1,   -1,   -1,   40,   -1,  268,  269,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  278,  279,  280,   -1,
  282,  283,  284,  285,  286,  287,  288,  289,  290,  291,
  292,  293,  294,  295,  296,  297,  298,  299,  300,  301,
  302,   -1,   -1,  305,   -1,   -1,   -1,  260,  261,  262,
  263,  264,  265,  266,  267,  268,  269,  270,  271,  272,
  273,  274,  275,  276,  277,   -1,   -1,   -1,   -1,   10,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  260,  261,
  262,  263,  264,  265,  266,  267,  257,  258,  259,   -1,
  401,  402,  403,  404,  405,  406,  407,  268,  269,   -1,
   41,   -1,   10,   44,   -1,   -1,  417,  278,  279,  280,
   -1,  282,  283,  284,  285,  286,  287,  288,  289,  290,
  291,  292,  293,  294,  295,  296,  297,  298,  299,  300,
  301,  302,   -1,   41,  305,   -1,   44,   -1,   -1,  257,
  258,  259,   -1,   -1,   -1,   -1,   -1,  409,   -1,  411,
  268,  269,   93,   -1,  416,   10,   -1,   -1,   -1,   -1,
  278,  279,  280,   -1,  282,  283,  284,  285,  286,  287,
  288,  289,  290,  291,  292,  293,  294,  295,  296,  297,
  298,  299,  300,  301,  302,   93,   41,  305,   -1,   44,
   -1,   -1,   -1,   10,  263,  264,  265,  266,  267,  268,
  269,  270,  271,  272,  273,  274,  275,  276,  277,   -1,
   10,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  257,  258,  259,   41,   -1,   -1,   44,   -1,   -1,
   -1,   -1,  268,  269,   -1,   -1,   -1,   -1,   93,   -1,
   -1,   41,  278,  279,   44,  416,  282,  283,  284,  285,
  286,  287,  288,  289,  290,  291,  292,  293,   10,   -1,
  296,  297,  298,  299,  300,  301,  302,   -1,   -1,  305,
   -1,   -1,   -1,   -1,   -1,   -1,   93,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   10,   -1,   -1,   -1,   -1,   41,
   -1,   -1,   44,   93,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   10,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   41,   10,   -1,   44,  260,
  261,  262,  263,  264,  265,  266,  267,  268,  269,  270,
  271,  272,  273,  274,   41,   -1,   -1,   44,   10,   -1,
   -1,   93,   -1,   -1,   -1,   -1,   -1,   41,   10,   -1,
   44,   -1,  260,  261,  262,  263,  264,  265,  266,  267,
  268,  269,  270,  271,  272,  273,  274,   93,   -1,   41,
   -1,   -1,   44,   -1,   -1,   -1,   -1,   -1,   -1,   41,
   -1,   -1,   44,   -1,   -1,   -1,   93,   -1,   -1,   -1,
   -1,   10,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   93,
   -1,   10,   -1,   -1,   -1,  260,  261,  262,  263,  264,
  265,  266,  267,  268,  269,  270,  271,  272,  273,  274,
   -1,   93,   41,   -1,   -1,   44,   -1,   -1,   -1,   -1,
   -1,   93,   41,   -1,   -1,   44,   -1,   -1,   -1,   -1,
   -1,   -1,   10,  260,  261,  262,  263,  264,  265,  266,
  267,  268,  269,  270,  271,  272,  273,  274,   -1,   -1,
  260,  261,  262,  263,  264,  265,  266,  267,  268,  269,
  270,  271,  272,   41,   93,   -1,   44,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   93,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   10,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   41,   -1,   -1,  260,  261,
  262,  263,  264,  265,  266,  267,  268,  269,  270,  271,
  272,   -1,   -1,   -1,   -1,   93,   -1,   41,   -1,   -1,
   44,   -1,   -1,   -1,  260,  261,  262,  263,  264,  265,
  266,  267,  268,  269,  270,  271,  272,   41,   -1,   10,
   -1,   -1,   -1,  260,  261,  262,  263,  264,  265,  266,
  267,  268,  269,  270,  271,  272,  260,  261,  262,  263,
  264,  265,  266,  267,  268,  269,  270,  271,  272,   93,
   41,   10,   -1,   44,   -1,   -1,   -1,   -1,  260,  261,
  262,  263,  264,  265,  266,  267,  268,  269,  260,  261,
  262,  263,  264,  265,  266,  267,  268,  269,   -1,   -1,
   -1,   -1,   41,   -1,   -1,   44,   -1,   -1,   -1,   -1,
   41,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   10,   -1,
   -1,   -1,   93,   -1,   -1,   -1,   10,   -1,   41,   -1,
   10,  260,  261,  262,  263,  264,  265,  266,  267,  268,
  269,  260,  261,  262,  263,  264,  265,  266,  267,   41,
   -1,   -1,   44,   -1,   93,   -1,   -1,   41,   -1,   -1,
   44,   41,   10,   -1,   44,   41,   10,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  260,  261,  262,  263,  264,  265,  266,  267,
   -1,   -1,   -1,   41,   -1,   -1,   44,   41,   -1,   -1,
   44,   93,   41,   -1,   -1,   -1,   -1,   -1,   -1,   93,
   -1,   -1,   -1,   93,  260,  261,  262,  263,  264,  265,
  266,  267,  268,  269,  270,  271,  272,  273,  274,  275,
  276,  277,   41,   -1,   -1,   -1,  260,  261,  262,  263,
  264,  265,  266,  267,   -1,   93,   -1,   -1,   -1,   93,
   41,   -1,   -1,   -1,   -1,   -1,  260,  261,  262,  263,
  264,  265,  266,  267,  268,  269,  270,  271,  272,  273,
  274,  275,  276,  277,   41,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  260,
  261,  262,  263,  264,  265,  266,  267,   41,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   41,   -1,   -1,   -1,   -1,
   -1,  260,  261,  262,  263,  264,  265,  266,  267,  260,
  261,  262,  263,  264,  265,  266,  267,  268,  269,  270,
  271,  272,  273,  274,  275,  276,  277,  260,  261,  262,
  263,  264,  265,  266,  267,  268,  269,  270,  271,  272,
  273,  274,  275,  276,  277,   41,   -1,   -1,  260,  261,
  262,  263,  264,  265,  266,  267,  260,  261,  262,   -1,
  260,  261,  262,   41,  260,  261,  262,  263,  264,  265,
  266,  267,  268,  269,  270,  271,  272,  273,  274,  275,
  276,  277,   41,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  260,  261,  262,   -1,  260,  261,  262,   -1,
   41,  260,  261,  262,  263,  264,  265,  266,  267,  268,
  269,  270,  271,  272,  273,  274,  275,  276,  277,   41,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  260,  261,  262,  263,  264,  265,  266,  267,  268,
  269,  270,  271,  272,  273,  274,  275,  276,  277,  260,
  261,  262,  263,  264,  265,  266,  267,  268,  269,  270,
  271,  272,  273,  274,  275,  276,  277,   41,   -1,   -1,
   -1,   -1,   -1,  260,  261,  262,  263,  264,  265,  266,
  267,  268,  269,  270,  271,  272,  273,  274,  275,  276,
  277,   41,   -1,   -1,   -1,   -1,  260,  261,  262,  263,
  264,  265,  266,  267,  268,  269,  270,  271,  272,  273,
  274,  275,  276,  277,  260,  261,  262,  263,  264,  265,
  266,  267,  268,  269,  270,  271,  272,  273,  274,  275,
  276,  277,   41,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   41,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  260,  261,  262,  263,  264,  265,
  266,  267,  268,  269,  270,  271,  272,  273,  274,  275,
  276,  277,  260,  261,  262,  263,  264,  265,  266,  267,
  268,  269,  270,  271,  272,  273,  274,  275,  276,  277,
   41,  260,  261,  262,  263,  264,  265,  266,  267,  268,
  269,  270,  271,  272,  273,  274,  275,  276,  277,  260,
  261,  262,  263,  264,  265,  266,  267,  268,  269,  270,
  271,  272,  273,  274,  275,  276,  277,   41,  260,  261,
  262,  263,  264,  265,  266,  267,  268,  269,  270,  271,
  272,  273,  274,  275,  276,  277,   41,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   41,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  260,  261,  262,  263,
  264,  265,  266,  267,  268,  269,  270,  271,  272,  273,
  274,  275,  276,  277,   41,   -1,   -1,   -1,   -1,   -1,
  260,  261,  262,  263,  264,  265,  266,  267,  268,  269,
  270,  271,  272,  273,  274,  275,  276,  277,   41,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   41,   -1,   -1,   -1,
   -1,  260,  261,  262,  263,  264,  265,  266,  267,  268,
  269,  270,  271,  272,  273,  274,  275,  276,  277,  260,
  261,  262,  263,  264,  265,  266,  267,  268,  269,  270,
  271,  272,  273,  274,  275,  276,  277,   44,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   44,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  260,
  261,  262,  263,  264,  265,  266,  267,  268,  269,  270,
  271,  272,  273,  274,  275,  276,  277,   44,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   44,  260,  261,  262,  263,
  264,  265,  266,  267,  268,  269,  270,  271,  272,  273,
  274,  275,  276,  277,   44,  260,  261,  262,  263,  264,
  265,  266,  267,  268,  269,  270,  271,  272,  273,  274,
  275,  276,  277,  260,  261,  262,  263,  264,  265,  266,
  267,  268,  269,  270,  271,  272,  273,  274,  275,  276,
  277,   44,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  260,  261,  262,  263,  264,  265,  266,
  267,  268,  269,  270,  271,  272,  273,  274,  275,  276,
  277,   -1,   -1,   -1,   -1,   -1,   -1,  260,  261,  262,
  263,  264,  265,  266,  267,  268,  269,  270,  271,  272,
  273,  274,  275,  276,  277,  260,  261,  262,  263,  264,
  265,  266,  267,  268,  269,  270,  271,  272,  273,  274,
  275,  276,  277,  260,  261,  262,  263,  264,  265,  266,
  267,  268,  269,  270,  271,  272,  273,  274,  275,  276,
  277,   -1,   -1,  260,  261,  262,  263,  264,  265,  266,
  267,  268,  269,  270,  271,  272,  273,  274,  275,  276,
  277,  260,  261,  262,  263,  264,  265,  266,  267,  268,
  269,  270,  271,  272,  273,  274,  275,  276,  277,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  260,  261,  262,  263,  264,  265,  266,
  267,  268,  269,  270,  271,  272,  273,  274,  275,  276,
  277,  260,  261,  262,  263,  264,  265,  266,  267,  268,
  269,  270,  271,  272,  273,  274,  275,  276,  277,   -1,
  260,  261,  262,  263,  264,  265,  266,  267,  268,  269,
  270,  271,  272,  273,  274,  275,  276,  277,  260,  261,
  262,  263,  264,  265,  266,  267,  268,  269,  270,  271,
  272,  273,  274,  275,  276,  277,   -1,  260,  261,  262,
  263,  264,  265,  266,  267,  268,  269,  270,  271,  272,
  273,  274,  275,  276,  277,  305,   -1,  307,   -1,  309,
  310,  311,  312,  313,  314,  315,  316,  317,  318,  319,
  320,  321,  322,  323,   -1,   -1,   -1,   -1,   -1,  329,
  330,  331,  332,  333,  334,   -1,  336,  337,  338,  339,
  340,  341,  342,  343,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  356,  357,  358,  359,
  360,  361,  362,  363,  364,  365,  366,  367,  368,  369,
  370,  371,  372,  373,  374,  375,  376,  377,  378,  379,
  380,  381,  382,  383,  384,  385,  386,  387,  388,  389,
  390,  391,  392,  393,  394,  395,  396,  397,  398,  399,
  400,  302,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  311,  312,   -1,   -1,   -1,   -1,   -1,   -1,  319,   -1,
   -1,   -1,   -1,   -1,  325,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  340,
   -1,   -1,  343,  344,   -1,  346,   -1,  348,  349,  350,
   -1,   -1,   -1,  354,  355,  356,   -1,  358,  359,  360,
  361,  362,  363,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  372,
};
#define YYFINAL 1
#ifndef YYDEBUG
#define YYDEBUG 0
#endif
#define YYMAXTOKEN 422
#define YYUNDFTOKEN 571
#define YYTRANSLATE(a) ((a) > YYMAXTOKEN ? YYUNDFTOKEN : (a))
#if YYDEBUG
static const char *const yyname[] = {

"end-of-file",0,0,0,0,0,0,0,0,0,"'\\n'",0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
0,0,0,0,0,0,0,0,0,"'('","')'",0,0,"','",0,0,0,0,0,0,0,0,0,0,0,0,0,"':'",0,0,0,0,
0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,"'['",0,"']'",0,0,0,0,0,
0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
"T_NUMBER","T_STRING","T_OP_LOGICNOT","T_OP_LOGICOR","T_OP_LOGICAND",
"T_OP_LOGICEQU","T_OP_LOGICGT","T_OP_LOGICLT","T_OP_LOGICGE","T_OP_LOGICLE",
"T_OP_LOGICNE","T_OP_ADD","T_OP_SUB","T_OP_OR","T_OP_XOR","T_OP_AND","T_OP_SHL",
"T_OP_SHR","T_OP_MUL","T_OP_DIV","T_OP_MOD","T_OP_NOT","T_OP_DEF","T_OP_BANK",
"T_OP_ALIGN","T_OP_SIN","T_OP_COS","T_OP_TAN","T_OP_ASIN","T_OP_ACOS",
"T_OP_ATAN","T_OP_ATAN2","T_OP_FDIV","T_OP_FMUL","T_OP_ROUND","T_OP_CEIL",
"T_OP_FLOOR","T_OP_HIGH","T_OP_LOW","T_OP_STRCMP","T_OP_STRIN","T_OP_STRSUB",
"T_OP_STRLEN","T_OP_STRCAT","T_OP_STRUPR","T_OP_STRLWR","NEG","T_LABEL","T_ID",
"T_POP_EQU","T_POP_SET","T_POP_EQUS","T_POP_INCLUDE","T_POP_PRINTF",
"T_POP_PRINTT","T_POP_PRINTV","T_POP_IF","T_POP_ELSE","T_POP_ENDC",
"T_POP_IMPORT","T_POP_EXPORT","T_POP_GLOBAL","T_POP_DB","T_POP_DS","T_POP_DW",
"T_POP_DL","T_POP_SECTION","T_POP_RB","T_POP_RW","T_POP_RL","T_POP_MACRO",
"T_POP_ENDM","T_POP_RSRESET","T_POP_RSSET","T_POP_INCBIN","T_POP_REPT",
"T_POP_CHARMAP","T_POP_SHIFT","T_POP_ENDR","T_POP_FAIL","T_POP_WARN",
"T_POP_PURGE","T_POP_POPS","T_POP_PUSHS","T_POP_POPO","T_POP_PUSHO","T_POP_OPT",
"T_SECT_WRAM0","T_SECT_VRAM","T_SECT_ROMX","T_SECT_ROM0","T_SECT_HRAM",
"T_SECT_WRAMX","T_SECT_SRAM","T_SECT_OAM","T_SECT_HOME","T_SECT_DATA",
"T_SECT_CODE","T_SECT_BSS","T_Z80_ADC","T_Z80_ADD","T_Z80_AND","T_Z80_BIT",
"T_Z80_CALL","T_Z80_CCF","T_Z80_CP","T_Z80_CPL","T_Z80_DAA","T_Z80_DEC",
"T_Z80_DI","T_Z80_EI","T_Z80_HALT","T_Z80_INC","T_Z80_JP","T_Z80_JR","T_Z80_LD",
"T_Z80_LDI","T_Z80_LDD","T_Z80_LDIO","T_Z80_NOP","T_Z80_OR","T_Z80_POP",
"T_Z80_PUSH","T_Z80_RES","T_Z80_RET","T_Z80_RETI","T_Z80_RST","T_Z80_RL",
"T_Z80_RLA","T_Z80_RLC","T_Z80_RLCA","T_Z80_RR","T_Z80_RRA","T_Z80_RRC",
"T_Z80_RRCA","T_Z80_SBC","T_Z80_SCF","T_Z80_STOP","T_Z80_SLA","T_Z80_SRA",
"T_Z80_SRL","T_Z80_SUB","T_Z80_SWAP","T_Z80_XOR","T_TOKEN_A","T_TOKEN_B",
"T_TOKEN_C","T_TOKEN_D","T_TOKEN_E","T_TOKEN_H","T_TOKEN_L","T_MODE_AF",
"T_MODE_BC","T_MODE_BC_IND","T_MODE_DE","T_MODE_DE_IND","T_MODE_SP",
"T_MODE_SP_IND","T_MODE_C_IND","T_MODE_HL","T_MODE_HL_IND","T_MODE_HL_INDDEC",
"T_MODE_HL_INDINC","T_CC_NZ","T_CC_Z","T_CC_NC",0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
0,0,0,0,0,0,0,0,0,0,0,0,"illegal-symbol",
};
static const char *const yyrule[] = {
"$accept : asmfile",
"asmfile : lines",
"lines :",
"lines : lines line '\\n'",
"line : label",
"line : label cpu_command",
"line : label macro",
"line : label simple_pseudoop",
"line : pseudoop",
"label :",
"label : T_LABEL",
"label : T_LABEL ':'",
"label : T_LABEL ':' ':'",
"$$1 :",
"macro : T_ID $$1 macroargs",
"macroargs :",
"macroargs : macroarg",
"macroargs : macroarg ',' macroargs",
"macroarg : T_STRING",
"pseudoop : equ",
"pseudoop : set",
"pseudoop : rb",
"pseudoop : rw",
"pseudoop : rl",
"pseudoop : equs",
"pseudoop : macrodef",
"simple_pseudoop : include",
"simple_pseudoop : printf",
"simple_pseudoop : printt",
"simple_pseudoop : printv",
"simple_pseudoop : if",
"simple_pseudoop : else",
"simple_pseudoop : endc",
"simple_pseudoop : import",
"simple_pseudoop : export",
"simple_pseudoop : global",
"simple_pseudoop : db",
"simple_pseudoop : dw",
"simple_pseudoop : dl",
"simple_pseudoop : ds",
"simple_pseudoop : section",
"simple_pseudoop : rsreset",
"simple_pseudoop : rsset",
"simple_pseudoop : incbin",
"simple_pseudoop : charmap",
"simple_pseudoop : rept",
"simple_pseudoop : shift",
"simple_pseudoop : fail",
"simple_pseudoop : warn",
"simple_pseudoop : purge",
"simple_pseudoop : pops",
"simple_pseudoop : pushs",
"simple_pseudoop : popo",
"simple_pseudoop : pusho",
"simple_pseudoop : opt",
"$$2 :",
"opt : T_POP_OPT $$2 opt_list",
"opt_list : opt_list_entry",
"opt_list : opt_list_entry ',' opt_list",
"opt_list_entry : T_STRING",
"popo : T_POP_POPO",
"pusho : T_POP_PUSHO",
"pops : T_POP_POPS",
"pushs : T_POP_PUSHS",
"fail : T_POP_FAIL string",
"warn : T_POP_WARN string",
"shift : T_POP_SHIFT",
"rept : T_POP_REPT uconst",
"macrodef : T_LABEL ':' T_POP_MACRO",
"equs : T_LABEL T_POP_EQUS string",
"rsset : T_POP_RSSET uconst",
"rsreset : T_POP_RSRESET",
"rl : T_LABEL T_POP_RL uconst",
"rw : T_LABEL T_POP_RW uconst",
"rb : T_LABEL T_POP_RB uconst",
"ds : T_POP_DS uconst",
"db : T_POP_DB constlist_8bit",
"dw : T_POP_DW constlist_16bit",
"dl : T_POP_DL constlist_32bit",
"$$3 :",
"purge : T_POP_PURGE $$3 purge_list",
"purge_list : purge_list_entry",
"purge_list : purge_list_entry ',' purge_list",
"purge_list_entry : T_ID",
"import : T_POP_IMPORT import_list",
"import_list : import_list_entry",
"import_list : import_list_entry ',' import_list",
"import_list_entry : T_ID",
"export : T_POP_EXPORT export_list",
"export_list : export_list_entry",
"export_list : export_list_entry ',' export_list",
"export_list_entry : T_ID",
"global : T_POP_GLOBAL global_list",
"global_list : global_list_entry",
"global_list : global_list_entry ',' global_list",
"global_list_entry : T_ID",
"equ : T_LABEL T_POP_EQU const",
"set : T_LABEL T_POP_SET const",
"include : T_POP_INCLUDE string",
"incbin : T_POP_INCBIN string",
"incbin : T_POP_INCBIN string ',' uconst ',' uconst",
"charmap : T_POP_CHARMAP string ',' string",
"charmap : T_POP_CHARMAP string ',' const",
"printt : T_POP_PRINTT string",
"printv : T_POP_PRINTV const",
"printf : T_POP_PRINTF const",
"if : T_POP_IF const",
"else : T_POP_ELSE",
"endc : T_POP_ENDC",
"const_3bit : const",
"constlist_8bit : constlist_8bit_entry",
"constlist_8bit : constlist_8bit_entry ',' constlist_8bit",
"constlist_8bit_entry :",
"constlist_8bit_entry : const_8bit",
"constlist_8bit_entry : string",
"constlist_16bit : constlist_16bit_entry",
"constlist_16bit : constlist_16bit_entry ',' constlist_16bit",
"constlist_16bit_entry :",
"constlist_16bit_entry : const_16bit",
"constlist_32bit : constlist_32bit_entry",
"constlist_32bit : constlist_32bit_entry ',' constlist_32bit",
"constlist_32bit_entry :",
"constlist_32bit_entry : relocconst",
"const_PCrel : relocconst",
"const_8bit : relocconst",
"const_16bit : relocconst",
"relocconst : T_ID",
"relocconst : T_NUMBER",
"relocconst : string",
"relocconst : T_OP_LOGICNOT relocconst",
"relocconst : relocconst T_OP_LOGICOR relocconst",
"relocconst : relocconst T_OP_LOGICAND relocconst",
"relocconst : relocconst T_OP_LOGICEQU relocconst",
"relocconst : relocconst T_OP_LOGICGT relocconst",
"relocconst : relocconst T_OP_LOGICLT relocconst",
"relocconst : relocconst T_OP_LOGICGE relocconst",
"relocconst : relocconst T_OP_LOGICLE relocconst",
"relocconst : relocconst T_OP_LOGICNE relocconst",
"relocconst : relocconst T_OP_ADD relocconst",
"relocconst : relocconst T_OP_SUB relocconst",
"relocconst : relocconst T_OP_XOR relocconst",
"relocconst : relocconst T_OP_OR relocconst",
"relocconst : relocconst T_OP_AND relocconst",
"relocconst : relocconst T_OP_SHL relocconst",
"relocconst : relocconst T_OP_SHR relocconst",
"relocconst : relocconst T_OP_MUL relocconst",
"relocconst : relocconst T_OP_DIV relocconst",
"relocconst : relocconst T_OP_MOD relocconst",
"relocconst : T_OP_ADD relocconst",
"relocconst : T_OP_SUB relocconst",
"relocconst : T_OP_NOT relocconst",
"relocconst : T_OP_HIGH '(' relocconst ')'",
"relocconst : T_OP_LOW '(' relocconst ')'",
"relocconst : T_OP_BANK '(' T_ID ')'",
"$$4 :",
"relocconst : T_OP_DEF $$4 '(' T_ID ')'",
"relocconst : T_OP_ROUND '(' const ')'",
"relocconst : T_OP_CEIL '(' const ')'",
"relocconst : T_OP_FLOOR '(' const ')'",
"relocconst : T_OP_FDIV '(' const ',' const ')'",
"relocconst : T_OP_FMUL '(' const ',' const ')'",
"relocconst : T_OP_SIN '(' const ')'",
"relocconst : T_OP_COS '(' const ')'",
"relocconst : T_OP_TAN '(' const ')'",
"relocconst : T_OP_ASIN '(' const ')'",
"relocconst : T_OP_ACOS '(' const ')'",
"relocconst : T_OP_ATAN '(' const ')'",
"relocconst : T_OP_ATAN2 '(' const ',' const ')'",
"relocconst : T_OP_STRCMP '(' string ',' string ')'",
"relocconst : T_OP_STRIN '(' string ',' string ')'",
"relocconst : T_OP_STRLEN '(' string ')'",
"relocconst : '(' relocconst ')'",
"uconst : const",
"const : T_ID",
"const : T_NUMBER",
"const : string",
"const : T_OP_LOGICNOT const",
"const : const T_OP_LOGICOR const",
"const : const T_OP_LOGICAND const",
"const : const T_OP_LOGICEQU const",
"const : const T_OP_LOGICGT const",
"const : const T_OP_LOGICLT const",
"const : const T_OP_LOGICGE const",
"const : const T_OP_LOGICLE const",
"const : const T_OP_LOGICNE const",
"const : const T_OP_ADD const",
"const : const T_OP_SUB const",
"const : T_ID T_OP_SUB T_ID",
"const : const T_OP_XOR const",
"const : const T_OP_OR const",
"const : const T_OP_AND const",
"const : const T_OP_SHL const",
"const : const T_OP_SHR const",
"const : const T_OP_MUL const",
"const : const T_OP_DIV const",
"const : const T_OP_MOD const",
"const : T_OP_ADD const",
"const : T_OP_SUB const",
"const : T_OP_NOT const",
"const : T_OP_ROUND '(' const ')'",
"const : T_OP_CEIL '(' const ')'",
"const : T_OP_FLOOR '(' const ')'",
"const : T_OP_FDIV '(' const ',' const ')'",
"const : T_OP_FMUL '(' const ',' const ')'",
"const : T_OP_SIN '(' const ')'",
"const : T_OP_COS '(' const ')'",
"const : T_OP_TAN '(' const ')'",
"const : T_OP_ASIN '(' const ')'",
"const : T_OP_ACOS '(' const ')'",
"const : T_OP_ATAN '(' const ')'",
"const : T_OP_ATAN2 '(' const ',' const ')'",
"$$5 :",
"const : T_OP_DEF $$5 '(' T_ID ')'",
"const : T_OP_STRCMP '(' string ',' string ')'",
"const : T_OP_STRIN '(' string ',' string ')'",
"const : T_OP_STRLEN '(' string ')'",
"const : '(' const ')'",
"string : T_STRING",
"string : T_OP_STRSUB '(' string ',' uconst ',' uconst ')'",
"string : T_OP_STRCAT '(' string ',' string ')'",
"string : T_OP_STRUPR '(' string ')'",
"string : T_OP_STRLWR '(' string ')'",
"section : T_POP_SECTION string ',' sectiontype",
"section : T_POP_SECTION string ',' sectiontype '[' uconst ']'",
"section : T_POP_SECTION string ',' sectiontype ',' T_OP_ALIGN '[' uconst ']'",
"section : T_POP_SECTION string ',' sectiontype ',' T_OP_BANK '[' uconst ']'",
"section : T_POP_SECTION string ',' sectiontype '[' uconst ']' ',' T_OP_BANK '[' uconst ']'",
"section : T_POP_SECTION string ',' sectiontype ',' T_OP_ALIGN '[' uconst ']' ',' T_OP_BANK '[' uconst ']'",
"section : T_POP_SECTION string ',' sectiontype ',' T_OP_BANK '[' uconst ']' ',' T_OP_ALIGN '[' uconst ']'",
"sectiontype : T_SECT_WRAM0",
"sectiontype : T_SECT_VRAM",
"sectiontype : T_SECT_ROMX",
"sectiontype : T_SECT_ROM0",
"sectiontype : T_SECT_HRAM",
"sectiontype : T_SECT_WRAMX",
"sectiontype : T_SECT_SRAM",
"sectiontype : T_SECT_OAM",
"sectiontype : T_SECT_HOME",
"sectiontype : T_SECT_DATA",
"sectiontype : T_SECT_CODE",
"sectiontype : T_SECT_BSS",
"cpu_command : z80_adc",
"cpu_command : z80_add",
"cpu_command : z80_and",
"cpu_command : z80_bit",
"cpu_command : z80_call",
"cpu_command : z80_ccf",
"cpu_command : z80_cp",
"cpu_command : z80_cpl",
"cpu_command : z80_daa",
"cpu_command : z80_dec",
"cpu_command : z80_di",
"cpu_command : z80_ei",
"cpu_command : z80_halt",
"cpu_command : z80_inc",
"cpu_command : z80_jp",
"cpu_command : z80_jr",
"cpu_command : z80_ld",
"cpu_command : z80_ldd",
"cpu_command : z80_ldi",
"cpu_command : z80_ldio",
"cpu_command : z80_nop",
"cpu_command : z80_or",
"cpu_command : z80_pop",
"cpu_command : z80_push",
"cpu_command : z80_res",
"cpu_command : z80_ret",
"cpu_command : z80_reti",
"cpu_command : z80_rl",
"cpu_command : z80_rla",
"cpu_command : z80_rlc",
"cpu_command : z80_rlca",
"cpu_command : z80_rr",
"cpu_command : z80_rra",
"cpu_command : z80_rrc",
"cpu_command : z80_rrca",
"cpu_command : z80_rst",
"cpu_command : z80_sbc",
"cpu_command : z80_scf",
"cpu_command : z80_set",
"cpu_command : z80_sla",
"cpu_command : z80_sra",
"cpu_command : z80_srl",
"cpu_command : z80_stop",
"cpu_command : z80_sub",
"cpu_command : z80_swap",
"cpu_command : z80_xor",
"z80_adc : T_Z80_ADC op_a_n",
"z80_adc : T_Z80_ADC op_a_r",
"z80_add : T_Z80_ADD op_a_n",
"z80_add : T_Z80_ADD op_a_r",
"z80_add : T_Z80_ADD op_hl_ss",
"z80_add : T_Z80_ADD T_MODE_SP comma const_8bit",
"z80_and : T_Z80_AND op_a_n",
"z80_and : T_Z80_AND op_a_r",
"z80_bit : T_Z80_BIT const_3bit comma reg_r",
"z80_call : T_Z80_CALL const_16bit",
"z80_call : T_Z80_CALL ccode comma const_16bit",
"z80_ccf : T_Z80_CCF",
"z80_cp : T_Z80_CP op_a_n",
"z80_cp : T_Z80_CP op_a_r",
"z80_cpl : T_Z80_CPL",
"z80_daa : T_Z80_DAA",
"z80_dec : T_Z80_DEC reg_r",
"z80_dec : T_Z80_DEC reg_ss",
"z80_di : T_Z80_DI",
"z80_ei : T_Z80_EI",
"z80_halt : T_Z80_HALT",
"z80_inc : T_Z80_INC reg_r",
"z80_inc : T_Z80_INC reg_ss",
"z80_jp : T_Z80_JP const_16bit",
"z80_jp : T_Z80_JP ccode comma const_16bit",
"z80_jp : T_Z80_JP T_MODE_HL_IND",
"z80_jp : T_Z80_JP T_MODE_HL",
"z80_jr : T_Z80_JR const_PCrel",
"z80_jr : T_Z80_JR ccode comma const_PCrel",
"z80_ldi : T_Z80_LDI T_MODE_HL_IND comma T_MODE_A",
"z80_ldi : T_Z80_LDI T_MODE_A comma T_MODE_HL",
"z80_ldi : T_Z80_LDI T_MODE_A comma T_MODE_HL_IND",
"z80_ldd : T_Z80_LDD T_MODE_HL_IND comma T_MODE_A",
"z80_ldd : T_Z80_LDD T_MODE_A comma T_MODE_HL",
"z80_ldd : T_Z80_LDD T_MODE_A comma T_MODE_HL_IND",
"z80_ldio : T_Z80_LDIO T_MODE_A comma op_mem_ind",
"z80_ldio : T_Z80_LDIO op_mem_ind comma T_MODE_A",
"z80_ld : z80_ld_mem",
"z80_ld : z80_ld_cind",
"z80_ld : z80_ld_rr",
"z80_ld : z80_ld_ss",
"z80_ld : z80_ld_hl",
"z80_ld : z80_ld_sp",
"z80_ld : z80_ld_r",
"z80_ld : z80_ld_a",
"z80_ld_hl : T_Z80_LD T_MODE_HL comma '[' T_MODE_SP const_8bit ']'",
"z80_ld_hl : T_Z80_LD T_MODE_HL comma T_MODE_SP const_8bit",
"z80_ld_hl : T_Z80_LD T_MODE_HL comma const_16bit",
"z80_ld_sp : T_Z80_LD T_MODE_SP comma T_MODE_HL",
"z80_ld_sp : T_Z80_LD T_MODE_SP comma const_16bit",
"z80_ld_mem : T_Z80_LD op_mem_ind comma T_MODE_SP",
"z80_ld_mem : T_Z80_LD op_mem_ind comma T_MODE_A",
"z80_ld_cind : T_Z80_LD T_MODE_C_IND comma T_MODE_A",
"z80_ld_rr : T_Z80_LD reg_rr comma T_MODE_A",
"z80_ld_r : T_Z80_LD reg_r comma const_8bit",
"z80_ld_r : T_Z80_LD reg_r comma reg_r",
"z80_ld_a : T_Z80_LD reg_r comma T_MODE_C_IND",
"z80_ld_a : T_Z80_LD reg_r comma reg_rr",
"z80_ld_a : T_Z80_LD reg_r comma op_mem_ind",
"z80_ld_ss : T_Z80_LD T_MODE_BC comma const_16bit",
"z80_ld_ss : T_Z80_LD T_MODE_DE comma const_16bit",
"z80_nop : T_Z80_NOP",
"z80_or : T_Z80_OR op_a_n",
"z80_or : T_Z80_OR op_a_r",
"z80_pop : T_Z80_POP reg_tt",
"z80_push : T_Z80_PUSH reg_tt",
"z80_res : T_Z80_RES const_3bit comma reg_r",
"z80_ret : T_Z80_RET",
"z80_ret : T_Z80_RET ccode",
"z80_reti : T_Z80_RETI",
"z80_rl : T_Z80_RL reg_r",
"z80_rla : T_Z80_RLA",
"z80_rlc : T_Z80_RLC reg_r",
"z80_rlca : T_Z80_RLCA",
"z80_rr : T_Z80_RR reg_r",
"z80_rra : T_Z80_RRA",
"z80_rrc : T_Z80_RRC reg_r",
"z80_rrca : T_Z80_RRCA",
"z80_rst : T_Z80_RST const_8bit",
"z80_sbc : T_Z80_SBC op_a_n",
"z80_sbc : T_Z80_SBC op_a_r",
"z80_scf : T_Z80_SCF",
"z80_set : T_POP_SET const_3bit comma reg_r",
"z80_sla : T_Z80_SLA reg_r",
"z80_sra : T_Z80_SRA reg_r",
"z80_srl : T_Z80_SRL reg_r",
"z80_stop : T_Z80_STOP",
"z80_sub : T_Z80_SUB op_a_n",
"z80_sub : T_Z80_SUB op_a_r",
"z80_swap : T_Z80_SWAP reg_r",
"z80_xor : T_Z80_XOR op_a_n",
"z80_xor : T_Z80_XOR op_a_r",
"op_mem_ind : '[' const_16bit ']'",
"op_hl_ss : reg_ss",
"op_hl_ss : T_MODE_HL comma reg_ss",
"op_a_r : reg_r",
"op_a_r : T_MODE_A comma reg_r",
"op_a_n : const_8bit",
"op_a_n : T_MODE_A comma const_8bit",
"comma : ','",
"T_MODE_A : T_TOKEN_A",
"T_MODE_A : T_OP_HIGH '(' T_MODE_AF ')'",
"T_MODE_B : T_TOKEN_B",
"T_MODE_B : T_OP_HIGH '(' T_MODE_BC ')'",
"T_MODE_C : T_TOKEN_C",
"T_MODE_C : T_OP_LOW '(' T_MODE_BC ')'",
"T_MODE_D : T_TOKEN_D",
"T_MODE_D : T_OP_HIGH '(' T_MODE_DE ')'",
"T_MODE_E : T_TOKEN_E",
"T_MODE_E : T_OP_LOW '(' T_MODE_DE ')'",
"T_MODE_H : T_TOKEN_H",
"T_MODE_H : T_OP_HIGH '(' T_MODE_HL ')'",
"T_MODE_L : T_TOKEN_L",
"T_MODE_L : T_OP_LOW '(' T_MODE_HL ')'",
"ccode : T_CC_NZ",
"ccode : T_CC_Z",
"ccode : T_CC_NC",
"ccode : T_TOKEN_C",
"reg_r : T_MODE_B",
"reg_r : T_MODE_C",
"reg_r : T_MODE_D",
"reg_r : T_MODE_E",
"reg_r : T_MODE_H",
"reg_r : T_MODE_L",
"reg_r : T_MODE_HL_IND",
"reg_r : T_MODE_A",
"reg_tt : T_MODE_BC",
"reg_tt : T_MODE_DE",
"reg_tt : T_MODE_HL",
"reg_tt : T_MODE_AF",
"reg_ss : T_MODE_BC",
"reg_ss : T_MODE_DE",
"reg_ss : T_MODE_HL",
"reg_ss : T_MODE_SP",
"reg_rr : T_MODE_BC_IND",
"reg_rr : T_MODE_DE_IND",
"reg_rr : T_MODE_HL_INDINC",
"reg_rr : T_MODE_HL_INDDEC",

};
#endif

int      yydebug;
int      yynerrs;

int      yyerrflag;
int      yychar;
YYSTYPE  yyval;
YYSTYPE  yylval;

/* define the initial stack-sizes */
#ifdef YYSTACKSIZE
#undef YYMAXDEPTH
#define YYMAXDEPTH  YYSTACKSIZE
#else
#ifdef YYMAXDEPTH
#define YYSTACKSIZE YYMAXDEPTH
#else
#define YYSTACKSIZE 10000
#define YYMAXDEPTH  10000
#endif
#endif

#define YYINITSTACKSIZE 200

typedef struct {
    unsigned stacksize;
    YYINT    *s_base;
    YYINT    *s_mark;
    YYINT    *s_last;
    YYSTYPE  *l_base;
    YYSTYPE  *l_mark;
} YYSTACKDATA;
/* variables for the parser stack */
static YYSTACKDATA yystack;

#if YYDEBUG
#include <stdio.h>	/* needed for printf */
#endif

#include <stdlib.h>	/* needed for malloc, etc */
#include <string.h>	/* needed for memset */

/* allocate initial stack or double stack size, up to YYMAXDEPTH */
static int yygrowstack(YYSTACKDATA *data)
{
    int i;
    unsigned newsize;
    YYINT *newss;
    YYSTYPE *newvs;

    if ((newsize = data->stacksize) == 0)
        newsize = YYINITSTACKSIZE;
    else if (newsize >= YYMAXDEPTH)
        return YYENOMEM;
    else if ((newsize *= 2) > YYMAXDEPTH)
        newsize = YYMAXDEPTH;

    i = (int) (data->s_mark - data->s_base);
    newss = (YYINT *)realloc(data->s_base, newsize * sizeof(*newss));
    if (newss == 0)
        return YYENOMEM;

    data->s_base = newss;
    data->s_mark = newss + i;

    newvs = (YYSTYPE *)realloc(data->l_base, newsize * sizeof(*newvs));
    if (newvs == 0)
        return YYENOMEM;

    data->l_base = newvs;
    data->l_mark = newvs + i;

    data->stacksize = newsize;
    data->s_last = data->s_base + newsize - 1;
    return 0;
}

#if YYPURE || defined(YY_NO_LEAKS)
static void yyfreestack(YYSTACKDATA *data)
{
    free(data->s_base);
    free(data->l_base);
    memset(data, 0, sizeof(*data));
}
#else
#define yyfreestack(data) /* nothing */
#endif

#define YYABORT  goto yyabort
#define YYREJECT goto yyabort
#define YYACCEPT goto yyaccept
#define YYERROR  goto yyerrlab

int
YYPARSE_DECL()
{
    int yym, yyn, yystate;
#if YYDEBUG
    const char *yys;

    if ((yys = getenv("YYDEBUG")) != 0)
    {
        yyn = *yys;
        if (yyn >= '0' && yyn <= '9')
            yydebug = yyn - '0';
    }
#endif

    yym = 0;
    yyn = 0;
    yynerrs = 0;
    yyerrflag = 0;
    yychar = YYEMPTY;
    yystate = 0;

#if YYPURE
    memset(&yystack, 0, sizeof(yystack));
#endif

    if (yystack.s_base == NULL && yygrowstack(&yystack) == YYENOMEM) goto yyoverflow;
    yystack.s_mark = yystack.s_base;
    yystack.l_mark = yystack.l_base;
    yystate = 0;
    *yystack.s_mark = 0;

yyloop:
    if ((yyn = yydefred[yystate]) != 0) goto yyreduce;
    if (yychar < 0)
    {
        yychar = YYLEX;
        if (yychar < 0) yychar = YYEOF;
#if YYDEBUG
        if (yydebug)
        {
            if ((yys = yyname[YYTRANSLATE(yychar)]) == NULL) yys = yyname[YYUNDFTOKEN];
            printf("%sdebug: state %d, reading %d (%s)\n",
                    YYPREFIX, yystate, yychar, yys);
        }
#endif
    }
    if (((yyn = yysindex[yystate]) != 0) && (yyn += yychar) >= 0 &&
            yyn <= YYTABLESIZE && yycheck[yyn] == (YYINT) yychar)
    {
#if YYDEBUG
        if (yydebug)
            printf("%sdebug: state %d, shifting to state %d\n",
                    YYPREFIX, yystate, yytable[yyn]);
#endif
        if (yystack.s_mark >= yystack.s_last && yygrowstack(&yystack) == YYENOMEM) goto yyoverflow;
        yystate = yytable[yyn];
        *++yystack.s_mark = yytable[yyn];
        *++yystack.l_mark = yylval;
        yychar = YYEMPTY;
        if (yyerrflag > 0)  --yyerrflag;
        goto yyloop;
    }
    if (((yyn = yyrindex[yystate]) != 0) && (yyn += yychar) >= 0 &&
            yyn <= YYTABLESIZE && yycheck[yyn] == (YYINT) yychar)
    {
        yyn = yytable[yyn];
        goto yyreduce;
    }
    if (yyerrflag != 0) goto yyinrecovery;

    YYERROR_CALL("syntax error");

    goto yyerrlab; /* redundant goto avoids 'unused label' warning */
yyerrlab:
    ++yynerrs;

yyinrecovery:
    if (yyerrflag < 3)
    {
        yyerrflag = 3;
        for (;;)
        {
            if (((yyn = yysindex[*yystack.s_mark]) != 0) && (yyn += YYERRCODE) >= 0 &&
                    yyn <= YYTABLESIZE && yycheck[yyn] == (YYINT) YYERRCODE)
            {
#if YYDEBUG
                if (yydebug)
                    printf("%sdebug: state %d, error recovery shifting\
 to state %d\n", YYPREFIX, *yystack.s_mark, yytable[yyn]);
#endif
                if (yystack.s_mark >= yystack.s_last && yygrowstack(&yystack) == YYENOMEM) goto yyoverflow;
                yystate = yytable[yyn];
                *++yystack.s_mark = yytable[yyn];
                *++yystack.l_mark = yylval;
                goto yyloop;
            }
            else
            {
#if YYDEBUG
                if (yydebug)
                    printf("%sdebug: error recovery discarding state %d\n",
                            YYPREFIX, *yystack.s_mark);
#endif
                if (yystack.s_mark <= yystack.s_base) goto yyabort;
                --yystack.s_mark;
                --yystack.l_mark;
            }
        }
    }
    else
    {
        if (yychar == YYEOF) goto yyabort;
#if YYDEBUG
        if (yydebug)
        {
            if ((yys = yyname[YYTRANSLATE(yychar)]) == NULL) yys = yyname[YYUNDFTOKEN];
            printf("%sdebug: state %d, error recovery discards token %d (%s)\n",
                    YYPREFIX, yystate, yychar, yys);
        }
#endif
        yychar = YYEMPTY;
        goto yyloop;
    }

yyreduce:
#if YYDEBUG
    if (yydebug)
        printf("%sdebug: state %d, reducing by rule %d (%s)\n",
                YYPREFIX, yystate, yyn, yyrule[yyn]);
#endif
    yym = yylen[yyn];
    if (yym > 0)
        yyval = yystack.l_mark[1-yym];
    else
        memset(&yyval, 0, sizeof yyval);

    switch (yyn)
    {
case 3:
#line 568 "src/asm/asmy.y"
	{
		nLineNo += 1;
		nTotalLines += 1;
	}
break;
case 10:
#line 580 "src/asm/asmy.y"
	{
		if (yystack.l_mark[0].tzSym[0] == '.')
			sym_AddLocalReloc(yystack.l_mark[0].tzSym);
		else
			sym_AddReloc(yystack.l_mark[0].tzSym);
	}
break;
case 11:
#line 585 "src/asm/asmy.y"
	{
		if (yystack.l_mark[-1].tzSym[0] == '.')
			sym_AddLocalReloc(yystack.l_mark[-1].tzSym);
		else
			sym_AddReloc(yystack.l_mark[-1].tzSym);
	}
break;
case 12:
#line 590 "src/asm/asmy.y"
	{
		if (yystack.l_mark[-2].tzSym[0] == '.') {
			sym_AddLocalReloc(yystack.l_mark[-2].tzSym);
		} else {
			sym_AddReloc(yystack.l_mark[-2].tzSym);
		}
		sym_Export(yystack.l_mark[-2].tzSym);
	}
break;
case 13:
#line 599 "src/asm/asmy.y"
	{
		yy_set_state(LEX_STATE_MACROARGS);
	}
break;
case 14:
#line 601 "src/asm/asmy.y"
	{
		yy_set_state(LEX_STATE_NORMAL);

		if (!fstk_RunMacro(yystack.l_mark[-2].tzSym)) {
			fatalerror("Macro '%s' not defined", yystack.l_mark[-2].tzSym);
		}
	}
break;
case 18:
#line 613 "src/asm/asmy.y"
	{
		sym_AddNewMacroArg(yystack.l_mark[0].tzString);
	}
break;
case 55:
#line 655 "src/asm/asmy.y"
	{
		yy_set_state(LEX_STATE_MACROARGS);
	}
break;
case 56:
#line 657 "src/asm/asmy.y"
	{
		yy_set_state(LEX_STATE_NORMAL);
	}
break;
case 59:
#line 664 "src/asm/asmy.y"
	{
		opt_Parse(yystack.l_mark[0].tzString);
	}
break;
case 60:
#line 668 "src/asm/asmy.y"
	{
		opt_Pop();
	}
break;
case 61:
#line 672 "src/asm/asmy.y"
	{
		opt_Push();
	}
break;
case 62:
#line 676 "src/asm/asmy.y"
	{
		out_PopSection();
	}
break;
case 63:
#line 680 "src/asm/asmy.y"
	{
		out_PushSection();
	}
break;
case 64:
#line 684 "src/asm/asmy.y"
	{
		fatalerror("%s", yystack.l_mark[0].tzString);
	}
break;
case 65:
#line 688 "src/asm/asmy.y"
	{
		warning("%s", yystack.l_mark[0].tzString);
	}
break;
case 66:
#line 693 "src/asm/asmy.y"
	{ sym_ShiftCurrentMacroArgs(); }
break;
case 67:
#line 697 "src/asm/asmy.y"
	{
						copyrept();
						fstk_RunRept( yystack.l_mark[0].nConstValue );
					}
break;
case 68:
#line 704 "src/asm/asmy.y"
	{
						copymacro();
						sym_AddMacro(yystack.l_mark[-2].tzSym);
					}
break;
case 69:
#line 711 "src/asm/asmy.y"
	{ sym_AddString( yystack.l_mark[-2].tzSym, yystack.l_mark[0].tzString ); }
break;
case 70:
#line 715 "src/asm/asmy.y"
	{ sym_AddSet( "_RS", yystack.l_mark[0].nConstValue ); }
break;
case 71:
#line 719 "src/asm/asmy.y"
	{ sym_AddSet( "_RS", 0 ); }
break;
case 72:
#line 723 "src/asm/asmy.y"
	{
						sym_AddEqu( yystack.l_mark[-2].tzSym, sym_GetConstantValue("_RS") );
						sym_AddSet( "_RS", sym_GetConstantValue("_RS")+4*yystack.l_mark[0].nConstValue );
					}
break;
case 73:
#line 730 "src/asm/asmy.y"
	{
						sym_AddEqu( yystack.l_mark[-2].tzSym, sym_GetConstantValue("_RS") );
						sym_AddSet( "_RS", sym_GetConstantValue("_RS")+2*yystack.l_mark[0].nConstValue );
					}
break;
case 74:
#line 737 "src/asm/asmy.y"
	{
						sym_AddEqu( yystack.l_mark[-2].tzSym, sym_GetConstantValue("_RS") );
						sym_AddSet( "_RS", sym_GetConstantValue("_RS")+yystack.l_mark[0].nConstValue );
					}
break;
case 75:
#line 744 "src/asm/asmy.y"
	{ out_Skip( yystack.l_mark[0].nConstValue ); }
break;
case 79:
#line 757 "src/asm/asmy.y"
	{
						oDontExpandStrings = true;
					}
break;
case 80:
#line 761 "src/asm/asmy.y"
	{
						oDontExpandStrings = false;
					}
break;
case 83:
#line 770 "src/asm/asmy.y"
	{ sym_Purge(yystack.l_mark[0].tzSym); }
break;
case 87:
#line 780 "src/asm/asmy.y"
	{
						/* This is done automatically if
						 * the label isn't found in the
						 * list of defined symbols. */
						if( nPass==1 )
							warning("IMPORT is a deprecated keyword with no effect: %s", yystack.l_mark[0].tzSym);
					}
break;
case 91:
#line 796 "src/asm/asmy.y"
	{ sym_Export(yystack.l_mark[0].tzSym); }
break;
case 95:
#line 806 "src/asm/asmy.y"
	{ sym_Global(yystack.l_mark[0].tzSym); }
break;
case 96:
#line 810 "src/asm/asmy.y"
	{ sym_AddEqu( yystack.l_mark[-2].tzSym, yystack.l_mark[0].nConstValue ); }
break;
case 97:
#line 814 "src/asm/asmy.y"
	{ sym_AddSet( yystack.l_mark[-2].tzSym, yystack.l_mark[0].nConstValue ); }
break;
case 98:
#line 818 "src/asm/asmy.y"
	{
						fstk_RunInclude(yystack.l_mark[0].tzString);
					}
break;
case 99:
#line 824 "src/asm/asmy.y"
	{ out_BinaryFile( yystack.l_mark[0].tzString ); }
break;
case 100:
#line 826 "src/asm/asmy.y"
	{
						out_BinaryFileSlice( yystack.l_mark[-4].tzString, yystack.l_mark[-2].nConstValue, yystack.l_mark[0].nConstValue );
					}
break;
case 101:
#line 832 "src/asm/asmy.y"
	{
						if(charmap_Add(yystack.l_mark[-2].tzString, yystack.l_mark[0].tzString[0] & 0xFF) == -1)
						{
							fprintf(stderr, "Error parsing charmap. Either you've added too many (%i), or the input character length is too long (%i)' : %s\n", MAXCHARMAPS, CHARMAPLENGTH, strerror(errno));
							yyerror("Error parsing charmap.");
						}
					}
break;
case 102:
#line 840 "src/asm/asmy.y"
	{
						if(charmap_Add(yystack.l_mark[-2].tzString, yystack.l_mark[0].nConstValue & 0xFF) == -1)
						{
							fprintf(stderr, "Error parsing charmap. Either you've added too many (%i), or the input character length is too long (%i)' : %s\n", MAXCHARMAPS, CHARMAPLENGTH, strerror(errno));
							yyerror("Error parsing charmap.");
						}
					}
break;
case 103:
#line 850 "src/asm/asmy.y"
	{
						if( nPass==1 )
							printf( "%s", yystack.l_mark[0].tzString );
					}
break;
case 104:
#line 857 "src/asm/asmy.y"
	{
						if( nPass==1 )
							printf( "$%lX", yystack.l_mark[0].nConstValue );
					}
break;
case 105:
#line 864 "src/asm/asmy.y"
	{
						if( nPass==1 )
							math_Print( yystack.l_mark[0].nConstValue );
					}
break;
case 106:
#line 871 "src/asm/asmy.y"
	{
						nIFDepth+=1;
						if( !yystack.l_mark[0].nConstValue )
						{
							if_skip_to_else();	/* will continue parsing just after ELSE or just at ENDC keyword */
						}
					}
break;
case 107:
#line 880 "src/asm/asmy.y"
	{
						if_skip_to_endc();		/* will continue parsing just at ENDC keyword */
					}
break;
case 108:
#line 886 "src/asm/asmy.y"
	{
						nIFDepth-=1;
					}
break;
case 109:
#line 892 "src/asm/asmy.y"
	{
						if( (yystack.l_mark[0].nConstValue<0) || (yystack.l_mark[0].nConstValue>7) )
						{
							yyerror("Immediate value must be 3-bit");
						}
						else
							yyval.nConstValue=yystack.l_mark[0].nConstValue&0x7;
					}
break;
case 112:
#line 906 "src/asm/asmy.y"
	{ out_Skip( 1 ); }
break;
case 113:
#line 907 "src/asm/asmy.y"
	{ out_RelByte( &yystack.l_mark[0].sVal ); }
break;
case 114:
#line 908 "src/asm/asmy.y"
	{ char *s; int length; s = yystack.l_mark[0].tzString; length = charmap_Convert(&s); out_AbsByteGroup(s, length); free(s); }
break;
case 117:
#line 915 "src/asm/asmy.y"
	{ out_Skip( 2 ); }
break;
case 118:
#line 916 "src/asm/asmy.y"
	{ out_RelWord( &yystack.l_mark[0].sVal ); }
break;
case 121:
#line 924 "src/asm/asmy.y"
	{ out_Skip( 4 ); }
break;
case 122:
#line 925 "src/asm/asmy.y"
	{ out_RelLong( &yystack.l_mark[0].sVal ); }
break;
case 123:
#line 930 "src/asm/asmy.y"
	{
						yyval.sVal = yystack.l_mark[0].sVal;
						if( !rpn_isPCRelative(&yystack.l_mark[0].sVal) )
							yyerror("Expression must be PC-relative");
					}
break;
case 124:
#line 938 "src/asm/asmy.y"
	{
						if( (!rpn_isReloc(&yystack.l_mark[0].sVal)) && ((yystack.l_mark[0].sVal.nVal<-128) || (yystack.l_mark[0].sVal.nVal>255)) )
						{
							yyerror("Expression must be 8-bit");
						}
						yyval.sVal=yystack.l_mark[0].sVal;
					}
break;
case 125:
#line 948 "src/asm/asmy.y"
	{
						if( (!rpn_isReloc(&yystack.l_mark[0].sVal)) && ((yystack.l_mark[0].sVal.nVal<-32768) || (yystack.l_mark[0].sVal.nVal>65535)) )
						{
							yyerror("Expression must be 16-bit");
						}
						yyval.sVal=yystack.l_mark[0].sVal;
					}
break;
case 126:
#line 959 "src/asm/asmy.y"
	{ rpn_Symbol(&yyval.sVal,yystack.l_mark[0].tzSym);	yyval.sVal.nVal = sym_GetValue(yystack.l_mark[0].tzSym); }
break;
case 127:
#line 961 "src/asm/asmy.y"
	{ rpn_Number(&yyval.sVal,yystack.l_mark[0].nConstValue);	yyval.sVal.nVal = yystack.l_mark[0].nConstValue; }
break;
case 128:
#line 963 "src/asm/asmy.y"
	{ char *s; int length; ULONG r; s = yystack.l_mark[0].tzString; length = charmap_Convert(&s); r = str2int2(s, length); free(s); rpn_Number(&yyval.sVal,r); yyval.sVal.nVal=r; }
break;
case 129:
#line 965 "src/asm/asmy.y"
	{ rpn_LOGNOT(&yyval.sVal,&yystack.l_mark[0].sVal); }
break;
case 130:
#line 967 "src/asm/asmy.y"
	{ rpn_LOGOR(&yyval.sVal,&yystack.l_mark[-2].sVal,&yystack.l_mark[0].sVal); }
break;
case 131:
#line 969 "src/asm/asmy.y"
	{ rpn_LOGAND(&yyval.sVal,&yystack.l_mark[-2].sVal,&yystack.l_mark[0].sVal); }
break;
case 132:
#line 971 "src/asm/asmy.y"
	{ rpn_LOGEQU(&yyval.sVal,&yystack.l_mark[-2].sVal,&yystack.l_mark[0].sVal); }
break;
case 133:
#line 973 "src/asm/asmy.y"
	{ rpn_LOGGT(&yyval.sVal,&yystack.l_mark[-2].sVal,&yystack.l_mark[0].sVal); }
break;
case 134:
#line 975 "src/asm/asmy.y"
	{ rpn_LOGLT(&yyval.sVal,&yystack.l_mark[-2].sVal,&yystack.l_mark[0].sVal); }
break;
case 135:
#line 977 "src/asm/asmy.y"
	{ rpn_LOGGE(&yyval.sVal,&yystack.l_mark[-2].sVal,&yystack.l_mark[0].sVal); }
break;
case 136:
#line 979 "src/asm/asmy.y"
	{ rpn_LOGLE(&yyval.sVal,&yystack.l_mark[-2].sVal,&yystack.l_mark[0].sVal); }
break;
case 137:
#line 981 "src/asm/asmy.y"
	{ rpn_LOGNE(&yyval.sVal,&yystack.l_mark[-2].sVal,&yystack.l_mark[0].sVal); }
break;
case 138:
#line 983 "src/asm/asmy.y"
	{ rpn_ADD(&yyval.sVal,&yystack.l_mark[-2].sVal,&yystack.l_mark[0].sVal); }
break;
case 139:
#line 985 "src/asm/asmy.y"
	{ rpn_SUB(&yyval.sVal,&yystack.l_mark[-2].sVal,&yystack.l_mark[0].sVal); }
break;
case 140:
#line 987 "src/asm/asmy.y"
	{ rpn_XOR(&yyval.sVal,&yystack.l_mark[-2].sVal,&yystack.l_mark[0].sVal); }
break;
case 141:
#line 989 "src/asm/asmy.y"
	{ rpn_OR(&yyval.sVal,&yystack.l_mark[-2].sVal,&yystack.l_mark[0].sVal); }
break;
case 142:
#line 991 "src/asm/asmy.y"
	{ rpn_AND(&yyval.sVal,&yystack.l_mark[-2].sVal,&yystack.l_mark[0].sVal); }
break;
case 143:
#line 993 "src/asm/asmy.y"
	{ rpn_SHL(&yyval.sVal,&yystack.l_mark[-2].sVal,&yystack.l_mark[0].sVal); }
break;
case 144:
#line 995 "src/asm/asmy.y"
	{ rpn_SHR(&yyval.sVal,&yystack.l_mark[-2].sVal,&yystack.l_mark[0].sVal); }
break;
case 145:
#line 997 "src/asm/asmy.y"
	{ rpn_MUL(&yyval.sVal,&yystack.l_mark[-2].sVal,&yystack.l_mark[0].sVal); }
break;
case 146:
#line 999 "src/asm/asmy.y"
	{ rpn_DIV(&yyval.sVal,&yystack.l_mark[-2].sVal,&yystack.l_mark[0].sVal); }
break;
case 147:
#line 1001 "src/asm/asmy.y"
	{ rpn_MOD(&yyval.sVal,&yystack.l_mark[-2].sVal,&yystack.l_mark[0].sVal); }
break;
case 148:
#line 1003 "src/asm/asmy.y"
	{ yyval.sVal = yystack.l_mark[0].sVal; }
break;
case 149:
#line 1005 "src/asm/asmy.y"
	{ rpn_UNNEG(&yyval.sVal,&yystack.l_mark[0].sVal); }
break;
case 150:
#line 1007 "src/asm/asmy.y"
	{ rpn_UNNOT(&yyval.sVal,&yystack.l_mark[0].sVal); }
break;
case 151:
#line 1009 "src/asm/asmy.y"
	{ rpn_HIGH(&yyval.sVal, &yystack.l_mark[-1].sVal); }
break;
case 152:
#line 1011 "src/asm/asmy.y"
	{ rpn_LOW(&yyval.sVal, &yystack.l_mark[-1].sVal); }
break;
case 153:
#line 1013 "src/asm/asmy.y"
	{ rpn_Bank(&yyval.sVal,yystack.l_mark[-1].tzSym); yyval.sVal.nVal = 0; }
break;
case 154:
#line 1014 "src/asm/asmy.y"
	{ oDontExpandStrings = true; }
break;
case 155:
#line 1015 "src/asm/asmy.y"
	{ rpn_Number(&yyval.sVal,sym_isConstDefined(yystack.l_mark[-1].tzSym)); oDontExpandStrings = false; }
break;
case 156:
#line 1016 "src/asm/asmy.y"
	{ rpn_Number(&yyval.sVal,math_Round(yystack.l_mark[-1].nConstValue)); }
break;
case 157:
#line 1017 "src/asm/asmy.y"
	{ rpn_Number(&yyval.sVal,math_Ceil(yystack.l_mark[-1].nConstValue)); }
break;
case 158:
#line 1018 "src/asm/asmy.y"
	{ rpn_Number(&yyval.sVal,math_Floor(yystack.l_mark[-1].nConstValue)); }
break;
case 159:
#line 1019 "src/asm/asmy.y"
	{ rpn_Number(&yyval.sVal,math_Div(yystack.l_mark[-3].nConstValue,yystack.l_mark[-1].nConstValue)); }
break;
case 160:
#line 1020 "src/asm/asmy.y"
	{ rpn_Number(&yyval.sVal,math_Mul(yystack.l_mark[-3].nConstValue,yystack.l_mark[-1].nConstValue)); }
break;
case 161:
#line 1021 "src/asm/asmy.y"
	{ rpn_Number(&yyval.sVal,math_Sin(yystack.l_mark[-1].nConstValue)); }
break;
case 162:
#line 1022 "src/asm/asmy.y"
	{ rpn_Number(&yyval.sVal,math_Cos(yystack.l_mark[-1].nConstValue)); }
break;
case 163:
#line 1023 "src/asm/asmy.y"
	{ rpn_Number(&yyval.sVal,math_Tan(yystack.l_mark[-1].nConstValue)); }
break;
case 164:
#line 1024 "src/asm/asmy.y"
	{ rpn_Number(&yyval.sVal,math_ASin(yystack.l_mark[-1].nConstValue)); }
break;
case 165:
#line 1025 "src/asm/asmy.y"
	{ rpn_Number(&yyval.sVal,math_ACos(yystack.l_mark[-1].nConstValue)); }
break;
case 166:
#line 1026 "src/asm/asmy.y"
	{ rpn_Number(&yyval.sVal,math_ATan(yystack.l_mark[-1].nConstValue)); }
break;
case 167:
#line 1027 "src/asm/asmy.y"
	{ rpn_Number(&yyval.sVal,math_ATan2(yystack.l_mark[-3].nConstValue,yystack.l_mark[-1].nConstValue)); }
break;
case 168:
#line 1028 "src/asm/asmy.y"
	{ rpn_Number(&yyval.sVal,strcmp(yystack.l_mark[-3].tzString,yystack.l_mark[-1].tzString)); }
break;
case 169:
#line 1030 "src/asm/asmy.y"
	{
						char	*p;
  						if( (p=strstr(yystack.l_mark[-3].tzString,yystack.l_mark[-1].tzString))!=NULL )
						{
							rpn_Number(&yyval.sVal,p-yystack.l_mark[-3].tzString+1);
						}
						else
						{
							rpn_Number(&yyval.sVal,0);
						}
					}
break;
case 170:
#line 1041 "src/asm/asmy.y"
	{ rpn_Number(&yyval.sVal,strlen(yystack.l_mark[-1].tzString)); }
break;
case 171:
#line 1043 "src/asm/asmy.y"
	{ yyval.sVal = yystack.l_mark[-1].sVal; }
break;
case 172:
#line 1047 "src/asm/asmy.y"
	{
						if(yystack.l_mark[0].nConstValue < 0)
							fatalerror("Constant mustn't be negative: %d", yystack.l_mark[0].nConstValue);
						yyval.nConstValue=yystack.l_mark[0].nConstValue;
					}
break;
case 173:
#line 1054 "src/asm/asmy.y"
	{ yyval.nConstValue = sym_GetConstantValue(yystack.l_mark[0].tzSym); }
break;
case 174:
#line 1055 "src/asm/asmy.y"
	{ yyval.nConstValue = yystack.l_mark[0].nConstValue; }
break;
case 175:
#line 1056 "src/asm/asmy.y"
	{ yyval.nConstValue = str2int(yystack.l_mark[0].tzString); }
break;
case 176:
#line 1057 "src/asm/asmy.y"
	{ yyval.nConstValue = !yystack.l_mark[0].nConstValue; }
break;
case 177:
#line 1058 "src/asm/asmy.y"
	{ yyval.nConstValue = yystack.l_mark[-2].nConstValue || yystack.l_mark[0].nConstValue; }
break;
case 178:
#line 1059 "src/asm/asmy.y"
	{ yyval.nConstValue = yystack.l_mark[-2].nConstValue && yystack.l_mark[0].nConstValue; }
break;
case 179:
#line 1060 "src/asm/asmy.y"
	{ yyval.nConstValue = yystack.l_mark[-2].nConstValue == yystack.l_mark[0].nConstValue; }
break;
case 180:
#line 1061 "src/asm/asmy.y"
	{ yyval.nConstValue = yystack.l_mark[-2].nConstValue > yystack.l_mark[0].nConstValue; }
break;
case 181:
#line 1062 "src/asm/asmy.y"
	{ yyval.nConstValue = yystack.l_mark[-2].nConstValue < yystack.l_mark[0].nConstValue; }
break;
case 182:
#line 1063 "src/asm/asmy.y"
	{ yyval.nConstValue = yystack.l_mark[-2].nConstValue >= yystack.l_mark[0].nConstValue; }
break;
case 183:
#line 1064 "src/asm/asmy.y"
	{ yyval.nConstValue = yystack.l_mark[-2].nConstValue <= yystack.l_mark[0].nConstValue; }
break;
case 184:
#line 1065 "src/asm/asmy.y"
	{ yyval.nConstValue = yystack.l_mark[-2].nConstValue != yystack.l_mark[0].nConstValue; }
break;
case 185:
#line 1066 "src/asm/asmy.y"
	{ yyval.nConstValue = yystack.l_mark[-2].nConstValue + yystack.l_mark[0].nConstValue; }
break;
case 186:
#line 1067 "src/asm/asmy.y"
	{ yyval.nConstValue = yystack.l_mark[-2].nConstValue - yystack.l_mark[0].nConstValue; }
break;
case 187:
#line 1069 "src/asm/asmy.y"
	{
						if (sym_IsRelocDiffDefined(yystack.l_mark[-2].tzSym, yystack.l_mark[0].tzSym) == 0)
							fatalerror("'%s - %s' not defined.", yystack.l_mark[-2].tzSym, yystack.l_mark[0].tzSym);
						yyval.nConstValue = sym_GetDefinedValue(yystack.l_mark[-2].tzSym) - sym_GetDefinedValue(yystack.l_mark[0].tzSym);
					}
break;
case 188:
#line 1074 "src/asm/asmy.y"
	{ yyval.nConstValue = yystack.l_mark[-2].nConstValue ^ yystack.l_mark[0].nConstValue; }
break;
case 189:
#line 1075 "src/asm/asmy.y"
	{ yyval.nConstValue = yystack.l_mark[-2].nConstValue | yystack.l_mark[0].nConstValue; }
break;
case 190:
#line 1076 "src/asm/asmy.y"
	{ yyval.nConstValue = yystack.l_mark[-2].nConstValue & yystack.l_mark[0].nConstValue; }
break;
case 191:
#line 1077 "src/asm/asmy.y"
	{ yyval.nConstValue = yystack.l_mark[-2].nConstValue << yystack.l_mark[0].nConstValue; }
break;
case 192:
#line 1078 "src/asm/asmy.y"
	{ yyval.nConstValue = yystack.l_mark[-2].nConstValue >> yystack.l_mark[0].nConstValue; }
break;
case 193:
#line 1079 "src/asm/asmy.y"
	{ yyval.nConstValue = yystack.l_mark[-2].nConstValue * yystack.l_mark[0].nConstValue; }
break;
case 194:
#line 1081 "src/asm/asmy.y"
	{
						if (yystack.l_mark[0].nConstValue == 0)
							fatalerror("division by zero");
						yyval.nConstValue = yystack.l_mark[-2].nConstValue / yystack.l_mark[0].nConstValue;
					}
break;
case 195:
#line 1087 "src/asm/asmy.y"
	{
						if (yystack.l_mark[0].nConstValue == 0)
							fatalerror("division by zero");
						yyval.nConstValue = yystack.l_mark[-2].nConstValue % yystack.l_mark[0].nConstValue;
					}
break;
case 196:
#line 1092 "src/asm/asmy.y"
	{ yyval.nConstValue = +yystack.l_mark[0].nConstValue; }
break;
case 197:
#line 1093 "src/asm/asmy.y"
	{ yyval.nConstValue = -yystack.l_mark[0].nConstValue; }
break;
case 198:
#line 1094 "src/asm/asmy.y"
	{ yyval.nConstValue = 0xFFFFFFFF^yystack.l_mark[0].nConstValue; }
break;
case 199:
#line 1095 "src/asm/asmy.y"
	{ yyval.nConstValue = math_Round(yystack.l_mark[-1].nConstValue); }
break;
case 200:
#line 1096 "src/asm/asmy.y"
	{ yyval.nConstValue = math_Ceil(yystack.l_mark[-1].nConstValue); }
break;
case 201:
#line 1097 "src/asm/asmy.y"
	{ yyval.nConstValue = math_Floor(yystack.l_mark[-1].nConstValue); }
break;
case 202:
#line 1098 "src/asm/asmy.y"
	{ yyval.nConstValue = math_Div(yystack.l_mark[-3].nConstValue,yystack.l_mark[-1].nConstValue); }
break;
case 203:
#line 1099 "src/asm/asmy.y"
	{ yyval.nConstValue = math_Mul(yystack.l_mark[-3].nConstValue,yystack.l_mark[-1].nConstValue); }
break;
case 204:
#line 1100 "src/asm/asmy.y"
	{ yyval.nConstValue = math_Sin(yystack.l_mark[-1].nConstValue); }
break;
case 205:
#line 1101 "src/asm/asmy.y"
	{ yyval.nConstValue = math_Cos(yystack.l_mark[-1].nConstValue); }
break;
case 206:
#line 1102 "src/asm/asmy.y"
	{ yyval.nConstValue = math_Tan(yystack.l_mark[-1].nConstValue); }
break;
case 207:
#line 1103 "src/asm/asmy.y"
	{ yyval.nConstValue = math_ASin(yystack.l_mark[-1].nConstValue); }
break;
case 208:
#line 1104 "src/asm/asmy.y"
	{ yyval.nConstValue = math_ACos(yystack.l_mark[-1].nConstValue); }
break;
case 209:
#line 1105 "src/asm/asmy.y"
	{ yyval.nConstValue = math_ATan(yystack.l_mark[-1].nConstValue); }
break;
case 210:
#line 1106 "src/asm/asmy.y"
	{ yyval.nConstValue = math_ATan2(yystack.l_mark[-3].nConstValue,yystack.l_mark[-1].nConstValue); }
break;
case 211:
#line 1107 "src/asm/asmy.y"
	{ oDontExpandStrings = true; }
break;
case 212:
#line 1107 "src/asm/asmy.y"
	{ yyval.nConstValue = sym_isConstDefined(yystack.l_mark[-1].tzSym); oDontExpandStrings = false; }
break;
case 213:
#line 1108 "src/asm/asmy.y"
	{ yyval.nConstValue = strcmp( yystack.l_mark[-3].tzString, yystack.l_mark[-1].tzString ); }
break;
case 214:
#line 1110 "src/asm/asmy.y"
	{
						char	*p;
  						if( (p=strstr(yystack.l_mark[-3].tzString,yystack.l_mark[-1].tzString))!=NULL )
						{
							yyval.nConstValue = p-yystack.l_mark[-3].tzString+1;
						}
						else
						{
							yyval.nConstValue = 0;
						}
					}
break;
case 215:
#line 1121 "src/asm/asmy.y"
	{ yyval.nConstValue = strlen(yystack.l_mark[-1].tzString); }
break;
case 216:
#line 1122 "src/asm/asmy.y"
	{ yyval.nConstValue = yystack.l_mark[-1].nConstValue; }
break;
case 217:
#line 1126 "src/asm/asmy.y"
	{ strcpy(yyval.tzString,yystack.l_mark[0].tzString); }
break;
case 218:
#line 1128 "src/asm/asmy.y"
	{ strncpy(yyval.tzString,yystack.l_mark[-5].tzString+yystack.l_mark[-3].nConstValue-1,yystack.l_mark[-1].nConstValue); yyval.tzString[yystack.l_mark[-1].nConstValue]=0; }
break;
case 219:
#line 1130 "src/asm/asmy.y"
	{ strcpy(yyval.tzString,yystack.l_mark[-3].tzString); strcat(yyval.tzString,yystack.l_mark[-1].tzString); }
break;
case 220:
#line 1132 "src/asm/asmy.y"
	{ strcpy(yyval.tzString,yystack.l_mark[-1].tzString); upperstring(yyval.tzString); }
break;
case 221:
#line 1134 "src/asm/asmy.y"
	{ strcpy(yyval.tzString,yystack.l_mark[-1].tzString); lowerstring(yyval.tzString); }
break;
case 222:
#line 1138 "src/asm/asmy.y"
	{
			out_NewSection(yystack.l_mark[-2].tzString,yystack.l_mark[0].nConstValue);
		}
break;
case 223:
#line 1142 "src/asm/asmy.y"
	{
			if( yystack.l_mark[-1].nConstValue>=0 && yystack.l_mark[-1].nConstValue<0x10000 )
				out_NewAbsSection(yystack.l_mark[-5].tzString,yystack.l_mark[-3].nConstValue,yystack.l_mark[-1].nConstValue,-1);
			else
				yyerror("Address $%x not 16-bit", yystack.l_mark[-1].nConstValue);
		}
break;
case 224:
#line 1149 "src/asm/asmy.y"
	{
			out_NewAlignedSection(yystack.l_mark[-7].tzString, yystack.l_mark[-5].nConstValue, yystack.l_mark[-1].nConstValue, -1);
		}
break;
case 225:
#line 1153 "src/asm/asmy.y"
	{
			bankrangecheck(yystack.l_mark[-7].tzString, yystack.l_mark[-5].nConstValue, -1, yystack.l_mark[-1].nConstValue);
		}
break;
case 226:
#line 1157 "src/asm/asmy.y"
	{
			if (yystack.l_mark[-6].nConstValue < 0 || yystack.l_mark[-6].nConstValue > 0x10000) {
				yyerror("Address $%x not 16-bit", yystack.l_mark[-6].nConstValue);
			}
			bankrangecheck(yystack.l_mark[-10].tzString, yystack.l_mark[-8].nConstValue, yystack.l_mark[-6].nConstValue, yystack.l_mark[-1].nConstValue);
		}
break;
case 227:
#line 1164 "src/asm/asmy.y"
	{
			out_NewAlignedSection(yystack.l_mark[-12].tzString, yystack.l_mark[-10].nConstValue, yystack.l_mark[-6].nConstValue, yystack.l_mark[-1].nConstValue);
		}
break;
case 228:
#line 1168 "src/asm/asmy.y"
	{
			out_NewAlignedSection(yystack.l_mark[-12].tzString, yystack.l_mark[-10].nConstValue, yystack.l_mark[-1].nConstValue, yystack.l_mark[-6].nConstValue);
		}
break;
case 229:
#line 1174 "src/asm/asmy.y"
	{ yyval.nConstValue=SECT_WRAM0; }
break;
case 230:
#line 1175 "src/asm/asmy.y"
	{ yyval.nConstValue=SECT_VRAM; }
break;
case 231:
#line 1176 "src/asm/asmy.y"
	{ yyval.nConstValue=SECT_ROMX; }
break;
case 232:
#line 1177 "src/asm/asmy.y"
	{ yyval.nConstValue=SECT_ROM0; }
break;
case 233:
#line 1178 "src/asm/asmy.y"
	{ yyval.nConstValue=SECT_HRAM; }
break;
case 234:
#line 1179 "src/asm/asmy.y"
	{ yyval.nConstValue=SECT_WRAMX; }
break;
case 235:
#line 1180 "src/asm/asmy.y"
	{ yyval.nConstValue=SECT_SRAM; }
break;
case 236:
#line 1181 "src/asm/asmy.y"
	{ yyval.nConstValue=SECT_OAM; }
break;
case 237:
#line 1182 "src/asm/asmy.y"
	{
					warning("HOME section name is deprecated, use ROM0 instead.");
					yyval.nConstValue=SECT_ROM0;
				}
break;
case 238:
#line 1186 "src/asm/asmy.y"
	{
					warning("DATA section name is deprecated, use ROMX instead.");
					yyval.nConstValue=SECT_ROMX;
				}
break;
case 239:
#line 1190 "src/asm/asmy.y"
	{
					warning("CODE section name is deprecated, use ROMX instead.");
					yyval.nConstValue=SECT_ROMX;
				}
break;
case 240:
#line 1194 "src/asm/asmy.y"
	{
					warning("BSS section name is deprecated, use WRAM0 instead.");
					yyval.nConstValue=SECT_WRAM0;
				}
break;
case 287:
#line 1249 "src/asm/asmy.y"
	{ out_AbsByte(0xCE); out_RelByte(&yystack.l_mark[0].sVal); }
break;
case 288:
#line 1250 "src/asm/asmy.y"
	{ out_AbsByte(0x88|yystack.l_mark[0].nConstValue); }
break;
case 289:
#line 1253 "src/asm/asmy.y"
	{ out_AbsByte(0xC6); out_RelByte(&yystack.l_mark[0].sVal); }
break;
case 290:
#line 1254 "src/asm/asmy.y"
	{ out_AbsByte(0x80|yystack.l_mark[0].nConstValue); }
break;
case 291:
#line 1255 "src/asm/asmy.y"
	{ out_AbsByte(0x09|(yystack.l_mark[0].nConstValue<<4)); }
break;
case 292:
#line 1257 "src/asm/asmy.y"
	{ out_AbsByte(0xE8); out_RelByte(&yystack.l_mark[0].sVal); }
break;
case 293:
#line 1261 "src/asm/asmy.y"
	{ out_AbsByte(0xE6); out_RelByte(&yystack.l_mark[0].sVal); }
break;
case 294:
#line 1262 "src/asm/asmy.y"
	{ out_AbsByte(0xA0|yystack.l_mark[0].nConstValue); }
break;
case 295:
#line 1266 "src/asm/asmy.y"
	{ out_AbsByte(0xCB); out_AbsByte(0x40|(yystack.l_mark[-2].nConstValue<<3)|yystack.l_mark[0].nConstValue); }
break;
case 296:
#line 1270 "src/asm/asmy.y"
	{ out_AbsByte(0xCD); out_RelWord(&yystack.l_mark[0].sVal); }
break;
case 297:
#line 1272 "src/asm/asmy.y"
	{ out_AbsByte(0xC4|(yystack.l_mark[-2].nConstValue<<3)); out_RelWord(&yystack.l_mark[0].sVal); }
break;
case 298:
#line 1276 "src/asm/asmy.y"
	{ out_AbsByte(0x3F); }
break;
case 299:
#line 1279 "src/asm/asmy.y"
	{ out_AbsByte(0xFE); out_RelByte(&yystack.l_mark[0].sVal); }
break;
case 300:
#line 1280 "src/asm/asmy.y"
	{ out_AbsByte(0xB8|yystack.l_mark[0].nConstValue); }
break;
case 301:
#line 1283 "src/asm/asmy.y"
	{ out_AbsByte(0x2F); }
break;
case 302:
#line 1286 "src/asm/asmy.y"
	{ out_AbsByte(0x27); }
break;
case 303:
#line 1290 "src/asm/asmy.y"
	{ out_AbsByte(0x05|(yystack.l_mark[0].nConstValue<<3)); }
break;
case 304:
#line 1292 "src/asm/asmy.y"
	{ out_AbsByte(0x0B|(yystack.l_mark[0].nConstValue<<4)); }
break;
case 305:
#line 1296 "src/asm/asmy.y"
	{ out_AbsByte(0xF3); }
break;
case 306:
#line 1300 "src/asm/asmy.y"
	{ out_AbsByte(0xFB); }
break;
case 307:
#line 1304 "src/asm/asmy.y"
	{
			out_AbsByte(0x76);
			if (CurrentOptions.haltnop) {
				out_AbsByte(0x00);
			}
		}
break;
case 308:
#line 1313 "src/asm/asmy.y"
	{ out_AbsByte(0x04|(yystack.l_mark[0].nConstValue<<3)); }
break;
case 309:
#line 1315 "src/asm/asmy.y"
	{ out_AbsByte(0x03|(yystack.l_mark[0].nConstValue<<4)); }
break;
case 310:
#line 1319 "src/asm/asmy.y"
	{ out_AbsByte(0xC3); out_RelWord(&yystack.l_mark[0].sVal); }
break;
case 311:
#line 1321 "src/asm/asmy.y"
	{ out_AbsByte(0xC2|(yystack.l_mark[-2].nConstValue<<3)); out_RelWord(&yystack.l_mark[0].sVal); }
break;
case 312:
#line 1323 "src/asm/asmy.y"
	{
						out_AbsByte(0xE9);
						if( nPass==1 )
							warning("'JP [HL]' is obsolete, use 'JP HL' instead.");
					}
break;
case 313:
#line 1329 "src/asm/asmy.y"
	{ out_AbsByte(0xE9); }
break;
case 314:
#line 1333 "src/asm/asmy.y"
	{ out_AbsByte(0x18); out_PCRelByte(&yystack.l_mark[0].sVal); }
break;
case 315:
#line 1335 "src/asm/asmy.y"
	{ out_AbsByte(0x20|(yystack.l_mark[-2].nConstValue<<3)); out_PCRelByte(&yystack.l_mark[0].sVal); }
break;
case 316:
#line 1339 "src/asm/asmy.y"
	{ out_AbsByte(0x02|(2<<4)); }
break;
case 317:
#line 1341 "src/asm/asmy.y"
	{
						out_AbsByte(0x0A|(2<<4));
						if( nPass==1 )
							warning("'LDI A,HL' is obsolete, use 'LDI A,[HL]' or 'LD A,[HL+] instead.");
					}
break;
case 318:
#line 1347 "src/asm/asmy.y"
	{ out_AbsByte(0x0A|(2<<4)); }
break;
case 319:
#line 1351 "src/asm/asmy.y"
	{ out_AbsByte(0x02|(3<<4)); }
break;
case 320:
#line 1353 "src/asm/asmy.y"
	{
						out_AbsByte(0x0A|(3<<4));
						if( nPass==1 )
							warning("'LDD A,HL' is obsolete, use 'LDD A,[HL]' or 'LD A,[HL-] instead.");
					}
break;
case 321:
#line 1359 "src/asm/asmy.y"
	{ out_AbsByte(0x0A|(3<<4)); }
break;
case 322:
#line 1363 "src/asm/asmy.y"
	{
						rpn_CheckHRAM(&yystack.l_mark[0].sVal,&yystack.l_mark[0].sVal);

						if( (!rpn_isReloc(&yystack.l_mark[0].sVal))
						&&	(yystack.l_mark[0].sVal.nVal<0 || (yystack.l_mark[0].sVal.nVal>0xFF && yystack.l_mark[0].sVal.nVal<0xFF00) || yystack.l_mark[0].sVal.nVal>0xFFFF) )
						{
							yyerror("Source address $%x not in $FF00 to $FFFF", yystack.l_mark[0].sVal.nVal);
						}

						out_AbsByte(0xF0);
						yystack.l_mark[0].sVal.nVal&=0xFF;
						out_RelByte(&yystack.l_mark[0].sVal);
					}
break;
case 323:
#line 1377 "src/asm/asmy.y"
	{
						rpn_CheckHRAM(&yystack.l_mark[-2].sVal,&yystack.l_mark[-2].sVal);

						if( (!rpn_isReloc(&yystack.l_mark[-2].sVal))
						&&	(yystack.l_mark[-2].sVal.nVal<0 || (yystack.l_mark[-2].sVal.nVal>0xFF && yystack.l_mark[-2].sVal.nVal<0xFF00) || yystack.l_mark[-2].sVal.nVal>0xFFFF) )
						{
							yyerror("Destination address $%x not in $FF00 to $FFFF", yystack.l_mark[-2].sVal.nVal);
						}

						out_AbsByte(0xE0);
						yystack.l_mark[-2].sVal.nVal&=0xFF;
						out_RelByte(&yystack.l_mark[-2].sVal);
					}
break;
case 332:
#line 1403 "src/asm/asmy.y"
	{
						out_AbsByte(0xF8); out_RelByte(&yystack.l_mark[-1].sVal);
						warning("'LD HL,[SP+e8]' is obsolete, use 'LD HL,SP+e8' instead.");
					}
break;
case 333:
#line 1408 "src/asm/asmy.y"
	{ out_AbsByte(0xF8); out_RelByte(&yystack.l_mark[0].sVal); }
break;
case 334:
#line 1410 "src/asm/asmy.y"
	{ out_AbsByte(0x01|(REG_HL<<4)); out_RelWord(&yystack.l_mark[0].sVal); }
break;
case 335:
#line 1413 "src/asm/asmy.y"
	{ out_AbsByte(0xF9); }
break;
case 336:
#line 1415 "src/asm/asmy.y"
	{ out_AbsByte(0x01|(REG_SP<<4)); out_RelWord(&yystack.l_mark[0].sVal); }
break;
case 337:
#line 1419 "src/asm/asmy.y"
	{ out_AbsByte(0x08); out_RelWord(&yystack.l_mark[-2].sVal); }
break;
case 338:
#line 1421 "src/asm/asmy.y"
	{
						if( (!rpn_isReloc(&yystack.l_mark[-2].sVal)) && yystack.l_mark[-2].sVal.nVal>=0xFF00)
						{
							out_AbsByte(0xE0);
							out_AbsByte(yystack.l_mark[-2].sVal.nVal&0xFF);
						}
						else
						{
							out_AbsByte(0xEA);
							out_RelWord(&yystack.l_mark[-2].sVal);
						}
					}
break;
case 339:
#line 1436 "src/asm/asmy.y"
	{ out_AbsByte(0xE2); }
break;
case 340:
#line 1440 "src/asm/asmy.y"
	{ out_AbsByte(0x02|(yystack.l_mark[-2].nConstValue<<4)); }
break;
case 341:
#line 1444 "src/asm/asmy.y"
	{ out_AbsByte(0x06|(yystack.l_mark[-2].nConstValue<<3)); out_RelByte(&yystack.l_mark[0].sVal); }
break;
case 342:
#line 1446 "src/asm/asmy.y"
	{
						if( (yystack.l_mark[-2].nConstValue==REG_HL_IND) && (yystack.l_mark[0].nConstValue==REG_HL_IND) )
						{
							yyerror("LD [HL],[HL] not a valid instruction");
						}
						else
							out_AbsByte(0x40|(yystack.l_mark[-2].nConstValue<<3)|yystack.l_mark[0].nConstValue);
					}
break;
case 343:
#line 1457 "src/asm/asmy.y"
	{
						if( yystack.l_mark[-2].nConstValue==REG_A )
							out_AbsByte(0xF2);
						else
						{
							yyerror("Destination operand must be A");
						}
					}
break;
case 344:
#line 1466 "src/asm/asmy.y"
	{
						if( yystack.l_mark[-2].nConstValue==REG_A )
							out_AbsByte(0x0A|(yystack.l_mark[0].nConstValue<<4));
						else
						{
							yyerror("Destination operand must be A");
						}
					}
break;
case 345:
#line 1475 "src/asm/asmy.y"
	{
						if( yystack.l_mark[-2].nConstValue==REG_A )
						{
							if( (!rpn_isReloc(&yystack.l_mark[0].sVal)) && yystack.l_mark[0].sVal.nVal>=0xFF00 )
							{
								out_AbsByte(0xF0);
								out_AbsByte(yystack.l_mark[0].sVal.nVal&0xFF);
							}
							else
							{
								out_AbsByte(0xFA);
								out_RelWord(&yystack.l_mark[0].sVal);
							}
						}
						else
						{
							yyerror("Destination operand must be A");
						}
					}
break;
case 346:
#line 1497 "src/asm/asmy.y"
	{ out_AbsByte(0x01|(REG_BC<<4)); out_RelWord(&yystack.l_mark[0].sVal); }
break;
case 347:
#line 1499 "src/asm/asmy.y"
	{ out_AbsByte(0x01|(REG_DE<<4)); out_RelWord(&yystack.l_mark[0].sVal); }
break;
case 348:
#line 1507 "src/asm/asmy.y"
	{ out_AbsByte(0x00); }
break;
case 349:
#line 1511 "src/asm/asmy.y"
	{ out_AbsByte(0xF6); out_RelByte(&yystack.l_mark[0].sVal); }
break;
case 350:
#line 1513 "src/asm/asmy.y"
	{ out_AbsByte(0xB0|yystack.l_mark[0].nConstValue); }
break;
case 351:
#line 1517 "src/asm/asmy.y"
	{ out_AbsByte(0xC1|(yystack.l_mark[0].nConstValue<<4)); }
break;
case 352:
#line 1521 "src/asm/asmy.y"
	{ out_AbsByte(0xC5|(yystack.l_mark[0].nConstValue<<4)); }
break;
case 353:
#line 1525 "src/asm/asmy.y"
	{ out_AbsByte(0xCB); out_AbsByte(0x80|(yystack.l_mark[-2].nConstValue<<3)|yystack.l_mark[0].nConstValue); }
break;
case 354:
#line 1529 "src/asm/asmy.y"
	{ out_AbsByte(0xC9); }
break;
case 355:
#line 1531 "src/asm/asmy.y"
	{ out_AbsByte(0xC0|(yystack.l_mark[0].nConstValue<<3)); }
break;
case 356:
#line 1535 "src/asm/asmy.y"
	{ out_AbsByte(0xD9); }
break;
case 357:
#line 1539 "src/asm/asmy.y"
	{ out_AbsByte(0xCB); out_AbsByte(0x10|yystack.l_mark[0].nConstValue); }
break;
case 358:
#line 1543 "src/asm/asmy.y"
	{ out_AbsByte(0x17); }
break;
case 359:
#line 1547 "src/asm/asmy.y"
	{ out_AbsByte(0xCB); out_AbsByte(0x00|yystack.l_mark[0].nConstValue); }
break;
case 360:
#line 1551 "src/asm/asmy.y"
	{ out_AbsByte(0x07); }
break;
case 361:
#line 1555 "src/asm/asmy.y"
	{ out_AbsByte(0xCB); out_AbsByte(0x18|yystack.l_mark[0].nConstValue); }
break;
case 362:
#line 1559 "src/asm/asmy.y"
	{ out_AbsByte(0x1F); }
break;
case 363:
#line 1563 "src/asm/asmy.y"
	{ out_AbsByte(0xCB); out_AbsByte(0x08|yystack.l_mark[0].nConstValue); }
break;
case 364:
#line 1567 "src/asm/asmy.y"
	{ out_AbsByte(0x0F); }
break;
case 365:
#line 1571 "src/asm/asmy.y"
	{
						if( rpn_isReloc(&yystack.l_mark[0].sVal) )
						{
							yyerror("Address for RST must be absolute");
						}
						else if( (yystack.l_mark[0].sVal.nVal&0x38)!=yystack.l_mark[0].sVal.nVal )
						{
							yyerror("Invalid address $%x for RST", yystack.l_mark[0].sVal.nVal);
						}
						else
							out_AbsByte(0xC7|yystack.l_mark[0].sVal.nVal);
					}
break;
case 366:
#line 1585 "src/asm/asmy.y"
	{ out_AbsByte(0xDE); out_RelByte(&yystack.l_mark[0].sVal); }
break;
case 367:
#line 1586 "src/asm/asmy.y"
	{ out_AbsByte(0x98|yystack.l_mark[0].nConstValue); }
break;
case 368:
#line 1590 "src/asm/asmy.y"
	{ out_AbsByte(0x37); }
break;
case 369:
#line 1594 "src/asm/asmy.y"
	{ out_AbsByte(0xCB); out_AbsByte(0xC0|(yystack.l_mark[-2].nConstValue<<3)|yystack.l_mark[0].nConstValue); }
break;
case 370:
#line 1598 "src/asm/asmy.y"
	{ out_AbsByte(0xCB); out_AbsByte(0x20|yystack.l_mark[0].nConstValue); }
break;
case 371:
#line 1602 "src/asm/asmy.y"
	{ out_AbsByte(0xCB); out_AbsByte(0x28|yystack.l_mark[0].nConstValue); }
break;
case 372:
#line 1606 "src/asm/asmy.y"
	{ out_AbsByte(0xCB); out_AbsByte(0x38|yystack.l_mark[0].nConstValue); }
break;
case 373:
#line 1610 "src/asm/asmy.y"
	{ out_AbsByte(0x10); out_AbsByte(0x00); }
break;
case 374:
#line 1613 "src/asm/asmy.y"
	{ out_AbsByte(0xD6); out_RelByte(&yystack.l_mark[0].sVal); }
break;
case 375:
#line 1614 "src/asm/asmy.y"
	{ out_AbsByte(0x90|yystack.l_mark[0].nConstValue); }
break;
case 376:
#line 1618 "src/asm/asmy.y"
	{ out_AbsByte(0xCB); out_AbsByte(0x30|yystack.l_mark[0].nConstValue); }
break;
case 377:
#line 1621 "src/asm/asmy.y"
	{ out_AbsByte(0xEE); out_RelByte(&yystack.l_mark[0].sVal); }
break;
case 378:
#line 1622 "src/asm/asmy.y"
	{ out_AbsByte(0xA8|yystack.l_mark[0].nConstValue); }
break;
case 379:
#line 1625 "src/asm/asmy.y"
	{ yyval.sVal = yystack.l_mark[-1].sVal; }
break;
case 380:
#line 1628 "src/asm/asmy.y"
	{ yyval.nConstValue = yystack.l_mark[0].nConstValue; }
break;
case 381:
#line 1629 "src/asm/asmy.y"
	{ yyval.nConstValue = yystack.l_mark[0].nConstValue; }
break;
case 382:
#line 1632 "src/asm/asmy.y"
	{ yyval.nConstValue = yystack.l_mark[0].nConstValue; }
break;
case 383:
#line 1633 "src/asm/asmy.y"
	{ yyval.nConstValue = yystack.l_mark[0].nConstValue; }
break;
case 384:
#line 1636 "src/asm/asmy.y"
	{ yyval.sVal = yystack.l_mark[0].sVal; }
break;
case 385:
#line 1637 "src/asm/asmy.y"
	{ yyval.sVal = yystack.l_mark[0].sVal; }
break;
case 401:
#line 1666 "src/asm/asmy.y"
	{ yyval.nConstValue = CC_NZ; }
break;
case 402:
#line 1667 "src/asm/asmy.y"
	{ yyval.nConstValue = CC_Z; }
break;
case 403:
#line 1668 "src/asm/asmy.y"
	{ yyval.nConstValue = CC_NC; }
break;
case 404:
#line 1669 "src/asm/asmy.y"
	{ yyval.nConstValue = CC_C; }
break;
case 405:
#line 1672 "src/asm/asmy.y"
	{ yyval.nConstValue = REG_B; }
break;
case 406:
#line 1673 "src/asm/asmy.y"
	{ yyval.nConstValue = REG_C; }
break;
case 407:
#line 1674 "src/asm/asmy.y"
	{ yyval.nConstValue = REG_D; }
break;
case 408:
#line 1675 "src/asm/asmy.y"
	{ yyval.nConstValue = REG_E; }
break;
case 409:
#line 1676 "src/asm/asmy.y"
	{ yyval.nConstValue = REG_H; }
break;
case 410:
#line 1677 "src/asm/asmy.y"
	{ yyval.nConstValue = REG_L; }
break;
case 411:
#line 1678 "src/asm/asmy.y"
	{ yyval.nConstValue = REG_HL_IND; }
break;
case 412:
#line 1679 "src/asm/asmy.y"
	{ yyval.nConstValue = REG_A; }
break;
case 413:
#line 1682 "src/asm/asmy.y"
	{ yyval.nConstValue = REG_BC; }
break;
case 414:
#line 1683 "src/asm/asmy.y"
	{ yyval.nConstValue = REG_DE; }
break;
case 415:
#line 1684 "src/asm/asmy.y"
	{ yyval.nConstValue = REG_HL; }
break;
case 416:
#line 1685 "src/asm/asmy.y"
	{ yyval.nConstValue = REG_AF; }
break;
case 417:
#line 1688 "src/asm/asmy.y"
	{ yyval.nConstValue = REG_BC; }
break;
case 418:
#line 1689 "src/asm/asmy.y"
	{ yyval.nConstValue = REG_DE; }
break;
case 419:
#line 1690 "src/asm/asmy.y"
	{ yyval.nConstValue = REG_HL; }
break;
case 420:
#line 1691 "src/asm/asmy.y"
	{ yyval.nConstValue = REG_SP; }
break;
case 421:
#line 1694 "src/asm/asmy.y"
	{ yyval.nConstValue = REG_BC_IND; }
break;
case 422:
#line 1695 "src/asm/asmy.y"
	{ yyval.nConstValue = REG_DE_IND; }
break;
case 423:
#line 1696 "src/asm/asmy.y"
	{ yyval.nConstValue = REG_HL_INDINC; }
break;
case 424:
#line 1697 "src/asm/asmy.y"
	{ yyval.nConstValue = REG_HL_INDDEC; }
break;
#line 3869 "src/asm/asmy.c"
    }
    yystack.s_mark -= yym;
    yystate = *yystack.s_mark;
    yystack.l_mark -= yym;
    yym = yylhs[yyn];
    if (yystate == 0 && yym == 0)
    {
#if YYDEBUG
        if (yydebug)
            printf("%sdebug: after reduction, shifting from state 0 to\
 state %d\n", YYPREFIX, YYFINAL);
#endif
        yystate = YYFINAL;
        *++yystack.s_mark = YYFINAL;
        *++yystack.l_mark = yyval;
        if (yychar < 0)
        {
            yychar = YYLEX;
            if (yychar < 0) yychar = YYEOF;
#if YYDEBUG
            if (yydebug)
            {
                if ((yys = yyname[YYTRANSLATE(yychar)]) == NULL) yys = yyname[YYUNDFTOKEN];
                printf("%sdebug: state %d, reading %d (%s)\n",
                        YYPREFIX, YYFINAL, yychar, yys);
            }
#endif
        }
        if (yychar == YYEOF) goto yyaccept;
        goto yyloop;
    }
    if (((yyn = yygindex[yym]) != 0) && (yyn += yystate) >= 0 &&
            yyn <= YYTABLESIZE && yycheck[yyn] == (YYINT) yystate)
        yystate = yytable[yyn];
    else
        yystate = yydgoto[yym];
#if YYDEBUG
    if (yydebug)
        printf("%sdebug: after reduction, shifting from state %d \
to state %d\n", YYPREFIX, *yystack.s_mark, yystate);
#endif
    if (yystack.s_mark >= yystack.s_last && yygrowstack(&yystack) == YYENOMEM) goto yyoverflow;
    *++yystack.s_mark = (YYINT) yystate;
    *++yystack.l_mark = yyval;
    goto yyloop;

yyoverflow:
    YYERROR_CALL("yacc stack overflow");

yyabort:
    yyfreestack(&yystack);
    return (1);

yyaccept:
    yyfreestack(&yystack);
    return (0);
}
